# This file is generated automatically by `build_database.py`. Change it there.
from sqf.expressions import BinaryExpression, UnaryExpression, NullExpression
from sqf.types import Keyword, Type, Nothing, String, Code, Array, Number, Boolean, Namespace, Object, Config, Script
from sqf.interpreter_types import WhileType, \
    ForType, SwitchType, IfType, TryType, WithType


EXPRESSIONS = [
    BinaryExpression(Number, Keyword('!='), Number, Boolean),
    BinaryExpression(String, Keyword('!='), String, Boolean),
    BinaryExpression(Object, Keyword('!='), Object, Boolean),
    BinaryExpression(Object, Keyword('!='), Object, Boolean),
    BinaryExpression(Object, Keyword('!='), Object, Boolean),
    BinaryExpression(String, Keyword('!='), String, Boolean),
    BinaryExpression(Config, Keyword('!='), Config, Boolean),
    BinaryExpression(Object, Keyword('!='), Object, Boolean),
    BinaryExpression(Object, Keyword('!='), Object, Boolean),
    BinaryExpression(Object, Keyword('!='), Object, Boolean),
    BinaryExpression(Object, Keyword('!='), Object, Boolean),
    BinaryExpression(Object, Keyword('!='), Object, Boolean),
    BinaryExpression(Object, Keyword('!='), Object, Boolean),
    BinaryExpression(Number, Keyword('%'), Number, Number),
    BinaryExpression(Boolean, Keyword('&&'), Boolean, Boolean),
    BinaryExpression(Boolean, Keyword('&&'), Code, Boolean),
    BinaryExpression(Number, Keyword('*'), Number, Number),
    BinaryExpression(Number, Keyword('+'), Number, Number),
    BinaryExpression(String, Keyword('+'), String, String),
    BinaryExpression(Array, Keyword('+'), Array, Array),
    BinaryExpression(Number, Keyword('-'), Number, Number),
    BinaryExpression(Array, Keyword('-'), Array, Array),
    BinaryExpression(Number, Keyword('/'), Number, Number),
    BinaryExpression(Config, Keyword('/'), String, Config),
    BinaryExpression(SwitchType, Keyword(':'), Code, Nothing),
    BinaryExpression(Number, Keyword('<'), Number, Boolean),
    BinaryExpression(Number, Keyword('<='), Number, Boolean),
    BinaryExpression(Number, Keyword('=='), Number, Boolean),
    BinaryExpression(String, Keyword('=='), String, Boolean),
    BinaryExpression(Object, Keyword('=='), Object, Boolean),
    BinaryExpression(Object, Keyword('=='), Object, Boolean),
    BinaryExpression(Object, Keyword('=='), Object, Boolean),
    BinaryExpression(String, Keyword('=='), String, Boolean),
    BinaryExpression(Config, Keyword('=='), Config, Boolean),
    BinaryExpression(Object, Keyword('=='), Object, Boolean),
    BinaryExpression(Object, Keyword('=='), Object, Boolean),
    BinaryExpression(Object, Keyword('=='), Object, Boolean),
    BinaryExpression(Object, Keyword('=='), Object, Boolean),
    BinaryExpression(Object, Keyword('=='), Object, Boolean),
    BinaryExpression(Object, Keyword('=='), Object, Boolean),
    BinaryExpression(Number, Keyword('>'), Number, Boolean),
    BinaryExpression(Number, Keyword('>='), Number, Boolean),
    BinaryExpression(Config, Keyword('>>'), String, Config),
    BinaryExpression(Object, Keyword('AddMagazineAmmoCargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('SwimInDepth'), Number, Nothing),
    BinaryExpression(Number, Keyword('^'), Number, Number),
    BinaryExpression(Object, Keyword('action'), Array, Nothing),
    BinaryExpression(Object, Keyword('actionParams'), Number, Array),
    BinaryExpression(Number, Keyword('add3DENLayer'), String, Number),
    BinaryExpression(Object, Keyword('addAction'), Array, Number),
    BinaryExpression(Object, Keyword('addBackpack'), String, Nothing),
    BinaryExpression(Object, Keyword('addBackpackCargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('addBackpackCargoGlobal'), Array, Nothing),
    BinaryExpression(Object, Keyword('addBackpackGlobal'), String, Nothing),
    BinaryExpression(Object, Keyword('addCuratorAddons'), Array, Nothing),
    BinaryExpression(Object, Keyword('addCuratorCameraArea'), Array, Nothing),
    BinaryExpression(Object, Keyword('addCuratorEditableObjects'), Array, Nothing),
    BinaryExpression(Object, Keyword('addCuratorEditingArea'), Array, Nothing),
    BinaryExpression(Object, Keyword('addCuratorPoints'), Number, Nothing),
    BinaryExpression(Object, Keyword('addEditorObject'), Array, String),
    BinaryExpression(Object, Keyword('addEventHandler'), Array, Number),
    BinaryExpression(Object, Keyword('addGoggles'), String, Nothing),
    BinaryExpression(Object, Keyword('addGroupIcon'), Array, Number),
    BinaryExpression(Object, Keyword('addHandgunItem'), String, Nothing),
    BinaryExpression(Object, Keyword('addHeadgear'), String, Nothing),
    BinaryExpression(Object, Keyword('addItem'), String, Nothing),
    BinaryExpression(Object, Keyword('addItemCargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('addItemCargoGlobal'), Array, Nothing),
    BinaryExpression(Object, Keyword('addItemToBackpack'), String, Nothing),
    BinaryExpression(Object, Keyword('addItemToUniform'), String, Nothing),
    BinaryExpression(Object, Keyword('addItemToVest'), String, Nothing),
    BinaryExpression(Object, Keyword('addLiveStats'), Number, Nothing),
    BinaryExpression(Object, Keyword('addMPEventHandler'), Array, Number),
    BinaryExpression(Object, Keyword('addMagazine'), String, Nothing),
    BinaryExpression(Object, Keyword('addMagazine'), Array, Nothing),
    BinaryExpression(Object, Keyword('addMagazineCargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('addMagazineCargoGlobal'), Array, Nothing),
    BinaryExpression(Object, Keyword('addMagazineGlobal'), String, Nothing),
    BinaryExpression(Object, Keyword('addMagazineTurret'), Array, Nothing),
    BinaryExpression(Object, Keyword('addMagazines'), Array, Nothing),
    BinaryExpression(Object, Keyword('addMenu'), Array, Number),
    BinaryExpression(Object, Keyword('addMenuItem'), Array, Number),
    BinaryExpression(Object, Keyword('addOwnedMine'), Object, Nothing),
    BinaryExpression(Object, Keyword('addPlayerScores'), Array, Nothing),
    BinaryExpression(Object, Keyword('addPrimaryWeaponItem'), String, Nothing),
    BinaryExpression(String, Keyword('addPublicVariableEventHandler'), Code, Nothing),
    BinaryExpression(String, Keyword('addPublicVariableEventHandler'), Array, Nothing),
    BinaryExpression(Object, Keyword('addRating'), Number, Nothing),
    BinaryExpression(Object, Keyword('addResources'), Array, Nothing),
    BinaryExpression(Object, Keyword('addScore'), Number, Nothing),
    BinaryExpression(Object, Keyword('addScoreSide'), Number, Nothing),
    BinaryExpression(Object, Keyword('addSecondaryWeaponItem'), String, Nothing),
    BinaryExpression(Object, Keyword('addTeamMember'), Object, Nothing),
    BinaryExpression(Object, Keyword('addUniform'), String, Nothing),
    BinaryExpression(Object, Keyword('addVehicle'), Object, Nothing),
    BinaryExpression(Object, Keyword('addVest'), String, Nothing),
    BinaryExpression(Object, Keyword('addWaypoint'), Array, Array),
    BinaryExpression(Object, Keyword('addWeapon'), String, Nothing),
    BinaryExpression(Object, Keyword('addWeaponCargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('addWeaponCargoGlobal'), Array, Nothing),
    BinaryExpression(Object, Keyword('addWeaponGlobal'), String, Nothing),
    BinaryExpression(Object, Keyword('addWeaponItem'), Array, Nothing),
    BinaryExpression(Object, Keyword('addWeaponTurret'), Array, Nothing),
    BinaryExpression(Object, Keyword('aimedAtTarget'), Array, Number),
    BinaryExpression(Object, Keyword('allow3DMode'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('allowCrewInImmobile'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('allowCuratorLogicIgnoreAreas'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('allowDamage'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('allowDammage'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('allowFileOperations'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('allowFleeing'), Number, Nothing),
    BinaryExpression(Object, Keyword('allowFleeing'), Number, Nothing),
    BinaryExpression(Array, Keyword('allowGetIn'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('allowSprint'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('ammo'), String, Number),
    BinaryExpression(Boolean, Keyword('and'), Boolean, Boolean),
    BinaryExpression(Boolean, Keyword('and'), Code, Boolean),
    BinaryExpression(Object, Keyword('animate'), Array, Nothing),
    BinaryExpression(Object, Keyword('animateDoor'), Array, Nothing),
    BinaryExpression(Object, Keyword('animateSource'), Array, Nothing),
    BinaryExpression(Object, Keyword('animationPhase'), String, Number),
    BinaryExpression(Object, Keyword('animationSourcePhase'), String, Number),
    BinaryExpression(Array, Keyword('append'), Array, Nothing),
    BinaryExpression(Array, Keyword('apply'), Code, Array),
    BinaryExpression(Array, Keyword('arrayIntersect'), Array, Array),
    BinaryExpression(Object, Keyword('assignAsCargo'), Object, Nothing),
    BinaryExpression(Object, Keyword('assignAsCargoIndex'), Array, Nothing),
    BinaryExpression(Object, Keyword('assignAsCommander'), Object, Nothing),
    BinaryExpression(Object, Keyword('assignAsDriver'), Object, Nothing),
    BinaryExpression(Object, Keyword('assignAsGunner'), Object, Nothing),
    BinaryExpression(Object, Keyword('assignAsTurret'), Array, Nothing),
    BinaryExpression(Object, Keyword('assignCurator'), Object, Nothing),
    BinaryExpression(Object, Keyword('assignItem'), String, Nothing),
    BinaryExpression(Object, Keyword('assignTeam'), String, Nothing),
    BinaryExpression(Object, Keyword('assignToAirport'), Object, Nothing),
    BinaryExpression(Object, Keyword('assignToAirport'), Number, Nothing),
    BinaryExpression(Number, Keyword('atan2'), Number, Number),
    BinaryExpression(Object, Keyword('attachObject'), Object, Nothing),
    BinaryExpression(Object, Keyword('attachTo'), Array, Nothing),
    BinaryExpression(Object, Keyword('backpackSpaceFor'), String, Array),
    BinaryExpression(Type, Keyword('breakOut'), String, Nothing),
    BinaryExpression(Object, Keyword('buildingExit'), Number, Array),
    BinaryExpression(Object, Keyword('buildingPos'), Number, Array),
    BinaryExpression(Object, Keyword('buttonSetAction'), String, Nothing),
    BinaryExpression(Type, Keyword('call'), Code, Nothing),
    BinaryExpression(String, Keyword('callExtension'), String, String),
    BinaryExpression(String, Keyword('callExtension'), Array, Array),
    BinaryExpression(Object, Keyword('camCommand'), String, Nothing),
    BinaryExpression(Object, Keyword('camCommit'), Number, Nothing),
    BinaryExpression(Object, Keyword('camCommitPrepared'), Number, Nothing),
    BinaryExpression(Object, Keyword('camConstuctionSetParams'), Array, Nothing),
    BinaryExpression(String, Keyword('camCreate'), Array, Object),
    BinaryExpression(Object, Keyword('camPreload'), Number, Nothing),
    BinaryExpression(Object, Keyword('camPrepareBank'), Number, Nothing),
    BinaryExpression(Object, Keyword('camPrepareDir'), Number, Nothing),
    BinaryExpression(Object, Keyword('camPrepareDive'), Number, Nothing),
    BinaryExpression(Object, Keyword('camPrepareFocus'), Array, Nothing),
    BinaryExpression(Object, Keyword('camPrepareFov'), Number, Nothing),
    BinaryExpression(Object, Keyword('camPrepareFovRange'), Array, Nothing),
    BinaryExpression(Object, Keyword('camPreparePos'), Array, Nothing),
    BinaryExpression(Object, Keyword('camPrepareRelPos'), Array, Nothing),
    BinaryExpression(Object, Keyword('camPrepareTarget'), Object, Nothing),
    BinaryExpression(Object, Keyword('camPrepareTarget'), Array, Nothing),
    BinaryExpression(Object, Keyword('camSetBank'), Number, Nothing),
    BinaryExpression(Object, Keyword('camSetDir'), Array, Nothing),
    BinaryExpression(Object, Keyword('camSetDive'), Number, Nothing),
    BinaryExpression(Object, Keyword('camSetFocus'), Array, Nothing),
    BinaryExpression(Object, Keyword('camSetFov'), Number, Nothing),
    BinaryExpression(Object, Keyword('camSetFovRange'), Array, Nothing),
    BinaryExpression(Object, Keyword('camSetPos'), Array, Nothing),
    BinaryExpression(Object, Keyword('camSetRelPos'), Array, Nothing),
    BinaryExpression(Object, Keyword('camSetTarget'), Object, Nothing),
    BinaryExpression(Object, Keyword('camSetTarget'), Array, Nothing),
    BinaryExpression(Object, Keyword('cameraEffect'), Array, Nothing),
    BinaryExpression(Object, Keyword('canAdd'), String, Boolean),
    BinaryExpression(Object, Keyword('canAdd'), Array, Boolean),
    BinaryExpression(Object, Keyword('canAddItemToBackpack'), String, Boolean),
    BinaryExpression(Object, Keyword('canAddItemToBackpack'), Array, Boolean),
    BinaryExpression(Object, Keyword('canAddItemToUniform'), String, Boolean),
    BinaryExpression(Object, Keyword('canAddItemToUniform'), Array, Boolean),
    BinaryExpression(Object, Keyword('canAddItemToVest'), String, Boolean),
    BinaryExpression(Object, Keyword('canAddItemToVest'), Array, Boolean),
    BinaryExpression(Object, Keyword('canSlingLoad'), Object, Boolean),
    BinaryExpression(Object, Keyword('canVehicleCargo'), Object, Array),
    BinaryExpression(TryType, Keyword('catch'), Code, Nothing),
    BinaryExpression(Object, Keyword('cbSetChecked'), Boolean, Nothing),
    BinaryExpression(Array, Keyword('checkVisibility'), Array, Number),
    BinaryExpression(Type, Keyword('clear3DENAttribute'), String, Nothing),
    BinaryExpression(Object, Keyword('closeDisplay'), Number, Nothing),
    BinaryExpression(Object, Keyword('commandArtilleryFire'), Array, Nothing),
    BinaryExpression(Array, Keyword('commandArtilleryFire'), Array, Nothing),
    BinaryExpression(Object, Keyword('commandChat'), String, Nothing),
    BinaryExpression(Array, Keyword('commandChat'), String, Nothing),
    BinaryExpression(Object, Keyword('commandFSM'), Array, Nothing),
    BinaryExpression(Array, Keyword('commandFSM'), Array, Nothing),
    BinaryExpression(Object, Keyword('commandFire'), Object, Nothing),
    BinaryExpression(Array, Keyword('commandFire'), Object, Nothing),
    BinaryExpression(Object, Keyword('commandFollow'), Object, Nothing),
    BinaryExpression(Array, Keyword('commandFollow'), Object, Nothing),
    BinaryExpression(Object, Keyword('commandMove'), Array, Nothing),
    BinaryExpression(Array, Keyword('commandMove'), Array, Nothing),
    BinaryExpression(Object, Keyword('commandRadio'), String, Nothing),
    BinaryExpression(Array, Keyword('commandRadio'), String, Nothing),
    BinaryExpression(Object, Keyword('commandSuppressiveFire'), Object, Nothing),
    BinaryExpression(Object, Keyword('commandSuppressiveFire'), Array, Nothing),
    BinaryExpression(Array, Keyword('commandSuppressiveFire'), Object, Nothing),
    BinaryExpression(Array, Keyword('commandSuppressiveFire'), Array, Nothing),
    BinaryExpression(Object, Keyword('commandTarget'), Object, Nothing),
    BinaryExpression(Array, Keyword('commandTarget'), Object, Nothing),
    BinaryExpression(Object, Keyword('commandWatch'), Array, Nothing),
    BinaryExpression(Array, Keyword('commandWatch'), Array, Nothing),
    BinaryExpression(Object, Keyword('commandWatch'), Object, Nothing),
    BinaryExpression(Array, Keyword('commandWatch'), Object, Nothing),
    BinaryExpression(String, Keyword('configClasses'), Config, Array),
    BinaryExpression(Object, Keyword('connectTerminalToUAV'), Object, Boolean),
    BinaryExpression(Object, Keyword('controlsGroupCtrl'), Number, Object),
    BinaryExpression(Object, Keyword('copyWaypoints'), Object, Nothing),
    BinaryExpression(Code, Keyword('count'), Array, Number),
    BinaryExpression(Object, Keyword('countEnemy'), Array, Number),
    BinaryExpression(Object, Keyword('countFriendly'), Array, Number),
    BinaryExpression(Object, Keyword('countSide'), Array, Number),
    BinaryExpression(String, Keyword('countType'), Array, Number),
    BinaryExpression(Object, Keyword('countUnknown'), Array, Number),
    BinaryExpression(Object, Keyword('create3DENEntity'), Array, Nothing),
    BinaryExpression(Object, Keyword('createDiaryRecord'), Array, Object),
    BinaryExpression(Object, Keyword('createDiarySubject'), Array, Number),
    BinaryExpression(Object, Keyword('createDisplay'), String, Object),
    BinaryExpression(Object, Keyword('createMPCampaignDisplay'), String, Nothing),
    BinaryExpression(Object, Keyword('createMenu'), Number, Nothing),
    BinaryExpression(Object, Keyword('createMissionDisplay'), String, Object),
    BinaryExpression(Object, Keyword('createMissionDisplay'), Array, Object),
    BinaryExpression(Object, Keyword('createSimpleTask'), Array, Object),
    BinaryExpression(String, Keyword('createSite'), Array, Object),
    BinaryExpression(Object, Keyword('createTask'), Array, Object),
    BinaryExpression(String, Keyword('createUnit'), Array, Nothing),
    BinaryExpression(Object, Keyword('createUnit'), Array, Object),
    BinaryExpression(String, Keyword('createVehicle'), Array, Object),
    BinaryExpression(String, Keyword('createVehicleLocal'), Array, Object),
    BinaryExpression(Object, Keyword('ctrlAddEventHandler'), Array, Number),
    BinaryExpression(Object, Keyword('ctrlCommit'), Number, Nothing),
    BinaryExpression(Object, Keyword('ctrlCreate'), Array, Object),
    BinaryExpression(Object, Keyword('ctrlEnable'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('ctrlMapAnimAdd'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlMapCursor'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlMapScreenToWorld'), Array, Array),
    BinaryExpression(Object, Keyword('ctrlMapWorldToScreen'), Array, Array),
    BinaryExpression(Object, Keyword('ctrlRemoveAllEventHandlers'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlRemoveEventHandler'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetActiveColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetAngle'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetAutoScrollDelay'), Number, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetAutoScrollRewind'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetAutoScrollSpeed'), Number, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetBackgroundColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetChecked'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetDisabledColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetEventHandler'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFade'), Number, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFont'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontH1'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontH1B'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontH2'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontH2B'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontH3'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontH3B'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontH4'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontH4B'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontH5'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontH5B'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontH6'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontH6B'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontHeight'), Number, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontHeightH1'), Number, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontHeightH2'), Number, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontHeightH3'), Number, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontHeightH4'), Number, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontHeightH5'), Number, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontHeightH6'), Number, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontHeightSecondary'), Number, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontP'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontP'), Number, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontPB'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetFontSecondary'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetForegroundColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetModel'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetModelDirAndUp'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetModelScale'), Number, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetPosition'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetScale'), Number, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetStructuredText'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetText'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetTextColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetTextColorSecondary'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetTextSecondary'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetTooltip'), String, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetTooltipColorBox'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetTooltipColorShade'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlSetTooltipColorText'), Array, Nothing),
    BinaryExpression(Object, Keyword('ctrlShow'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('curatorCoef'), String, Number),
    BinaryExpression(Object, Keyword('currentMagazineDetailTurret'), Array, String),
    BinaryExpression(Object, Keyword('currentMagazineTurret'), Array, String),
    BinaryExpression(Object, Keyword('currentWeaponTurret'), Array, String),
    BinaryExpression(Object, Keyword('customChat'), Array, Nothing),
    BinaryExpression(Object, Keyword('customRadio'), Array, Nothing),
    BinaryExpression(String, Keyword('cutFadeOut'), Number, Number),
    BinaryExpression(Number, Keyword('cutFadeOut'), Number, Nothing),
    BinaryExpression(String, Keyword('cutObj'), Array, Number),
    BinaryExpression(Number, Keyword('cutObj'), Array, Nothing),
    BinaryExpression(String, Keyword('cutRsc'), Array, Number),
    BinaryExpression(Number, Keyword('cutRsc'), Array, Nothing),
    BinaryExpression(String, Keyword('cutText'), Array, Number),
    BinaryExpression(Number, Keyword('cutText'), Array, Nothing),
    BinaryExpression(Number, Keyword('debugFSM'), Boolean, Nothing),
    BinaryExpression(Array, Keyword('deleteAt'), Number, Nothing),
    BinaryExpression(Object, Keyword('deleteEditorObject'), String, Nothing),
    BinaryExpression(Object, Keyword('deleteGroupWhenEmpty'), Boolean, Nothing),
    BinaryExpression(Array, Keyword('deleteRange'), Array, Nothing),
    BinaryExpression(Object, Keyword('deleteResources'), Array, Nothing),
    BinaryExpression(Object, Keyword('deleteVehicleCrew'), Object, Nothing),
    BinaryExpression(Object, Keyword('diarySubjectExists'), String, Boolean),
    BinaryExpression(Object, Keyword('directSay'), String, Nothing),
    BinaryExpression(Object, Keyword('disableAI'), String, Nothing),
    BinaryExpression(Object, Keyword('disableCollisionWith'), Object, Nothing),
    BinaryExpression(Object, Keyword('disableConversation'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('disableNVGEquipment'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('disableTIEquipment'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('disableUAVConnectability'), Array, Nothing),
    BinaryExpression(Object, Keyword('displayAddEventHandler'), Array, Number),
    BinaryExpression(Object, Keyword('displayCtrl'), Number, Object),
    BinaryExpression(Object, Keyword('displayRemoveAllEventHandlers'), String, Nothing),
    BinaryExpression(Object, Keyword('displayRemoveEventHandler'), Array, Nothing),
    BinaryExpression(Object, Keyword('displaySetEventHandler'), Array, Nothing),
    BinaryExpression(Object, Keyword('distance'), Object, Number),
    BinaryExpression(Object, Keyword('distance'), Array, Number),
    BinaryExpression(Array, Keyword('distance'), Object, Number),
    BinaryExpression(Array, Keyword('distance'), Array, Number),
    BinaryExpression(Object, Keyword('distance'), Object, Number),
    BinaryExpression(Object, Keyword('distance'), Array, Number),
    BinaryExpression(Array, Keyword('distance'), Object, Number),
    BinaryExpression(Object, Keyword('distance2D'), Object, Number),
    BinaryExpression(Object, Keyword('distance2D'), Array, Number),
    BinaryExpression(Array, Keyword('distance2D'), Object, Number),
    BinaryExpression(Array, Keyword('distance2D'), Array, Number),
    BinaryExpression(Object, Keyword('distanceSqr'), Object, Number),
    BinaryExpression(Object, Keyword('distanceSqr'), Array, Number),
    BinaryExpression(Array, Keyword('distanceSqr'), Object, Number),
    BinaryExpression(Array, Keyword('distanceSqr'), Array, Number),
    BinaryExpression(Object, Keyword('distanceSqr'), Object, Number),
    BinaryExpression(Object, Keyword('distanceSqr'), Array, Number),
    BinaryExpression(Array, Keyword('distanceSqr'), Object, Number),
    BinaryExpression(WhileType, Keyword('do'), Code, Nothing),
    BinaryExpression(WithType, Keyword('do'), Code, Nothing),
    BinaryExpression(ForType, Keyword('do'), Code, Nothing),
    BinaryExpression(SwitchType, Keyword('do'), Code, Nothing),
    BinaryExpression(Object, Keyword('doArtilleryFire'), Array, Nothing),
    BinaryExpression(Array, Keyword('doArtilleryFire'), Array, Nothing),
    BinaryExpression(Object, Keyword('doFSM'), Array, Nothing),
    BinaryExpression(Array, Keyword('doFSM'), Array, Nothing),
    BinaryExpression(Object, Keyword('doFire'), Object, Nothing),
    BinaryExpression(Array, Keyword('doFire'), Object, Nothing),
    BinaryExpression(Object, Keyword('doFollow'), Object, Nothing),
    BinaryExpression(Array, Keyword('doFollow'), Object, Nothing),
    BinaryExpression(Object, Keyword('doMove'), Array, Nothing),
    BinaryExpression(Array, Keyword('doMove'), Array, Nothing),
    BinaryExpression(Object, Keyword('doSuppressiveFire'), Object, Nothing),
    BinaryExpression(Object, Keyword('doSuppressiveFire'), Array, Nothing),
    BinaryExpression(Array, Keyword('doSuppressiveFire'), Object, Nothing),
    BinaryExpression(Array, Keyword('doSuppressiveFire'), Array, Nothing),
    BinaryExpression(Object, Keyword('doTarget'), Object, Nothing),
    BinaryExpression(Array, Keyword('doTarget'), Object, Nothing),
    BinaryExpression(Object, Keyword('doWatch'), Array, Nothing),
    BinaryExpression(Array, Keyword('doWatch'), Array, Nothing),
    BinaryExpression(Object, Keyword('doWatch'), Object, Nothing),
    BinaryExpression(Array, Keyword('doWatch'), Object, Nothing),
    BinaryExpression(Object, Keyword('doorPhase'), String, Number),
    BinaryExpression(Object, Keyword('drawArrow'), Array, Nothing),
    BinaryExpression(Object, Keyword('drawEllipse'), Array, Nothing),
    BinaryExpression(Object, Keyword('drawIcon'), Array, Nothing),
    BinaryExpression(Object, Keyword('drawLine'), Array, Nothing),
    BinaryExpression(Object, Keyword('drawLink'), Array, Nothing),
    BinaryExpression(Object, Keyword('drawLocation'), Object, Nothing),
    BinaryExpression(Object, Keyword('drawPolygon'), Array, Nothing),
    BinaryExpression(Object, Keyword('drawRectangle'), Array, Nothing),
    BinaryExpression(Object, Keyword('editObject'), String, Nothing),
    BinaryExpression(Object, Keyword('editorSetEventHandler'), Array, Nothing),
    BinaryExpression(Code, Keyword('else'), Code, Array),
    BinaryExpression(Object, Keyword('emptyPositions'), String, Number),
    BinaryExpression(Object, Keyword('enableAI'), String, Nothing),
    BinaryExpression(String, Keyword('enableAIFeature'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableAimPrecision'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableAttack'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableAttack'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableAutoStartUpRTD'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableAutoTrimRTD'), Boolean, Boolean),
    BinaryExpression(Number, Keyword('enableChannel'), Boolean, Nothing),
    BinaryExpression(Number, Keyword('enableChannel'), Array, Nothing),
    BinaryExpression(Object, Keyword('enableCollisionWith'), Object, Nothing),
    BinaryExpression(Object, Keyword('enableCopilot'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableDynamicSimulation'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableDynamicSimulation'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableFatigue'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableGunLights'), String, Nothing),
    BinaryExpression(Object, Keyword('enableGunLights'), String, Nothing),
    BinaryExpression(Object, Keyword('enableIRLasers'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableIRLasers'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableMimics'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enablePersonTurret'), Array, Nothing),
    BinaryExpression(Object, Keyword('enableReload'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableRopeAttach'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableSimulation'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableSimulationGlobal'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableStamina'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableUAVConnectability'), Array, Nothing),
    BinaryExpression(Object, Keyword('enableUAVWaypoints'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableVehicleCargo'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('enableWeaponDisassembly'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('engineOn'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('evalObjectArgument'), Array, Nothing),
    BinaryExpression(Type, Keyword('exec'), String, Nothing),
    BinaryExpression(Object, Keyword('execEditorScript'), Array, Nothing),
    BinaryExpression(Type, Keyword('execFSM'), String, Number),
    BinaryExpression(Type, Keyword('execVM'), String, Script),
    BinaryExpression(IfType, Keyword('exitWith'), Code, Nothing),
    BinaryExpression(Number, Keyword('fadeMusic'), Number, Nothing),
    BinaryExpression(Number, Keyword('fadeRadio'), Number, Nothing),
    BinaryExpression(Number, Keyword('fadeSound'), Number, Nothing),
    BinaryExpression(Number, Keyword('fadeSpeech'), Number, Nothing),
    BinaryExpression(Array, Keyword('find'), Type, Number),
    BinaryExpression(String, Keyword('find'), String, Number),
    BinaryExpression(Object, Keyword('findCover'), Array, Object),
    BinaryExpression(Object, Keyword('findEditorObject'), Array, String),
    BinaryExpression(Object, Keyword('findEditorObject'), Type, String),
    BinaryExpression(Array, Keyword('findEmptyPosition'), Array, Array),
    BinaryExpression(Array, Keyword('findEmptyPositionReady'), Array, Boolean),
    BinaryExpression(Object, Keyword('findNearestEnemy'), Object, Object),
    BinaryExpression(Object, Keyword('findNearestEnemy'), Array, Object),
    BinaryExpression(Object, Keyword('fire'), String, Nothing),
    BinaryExpression(Object, Keyword('fire'), Array, Nothing),
    BinaryExpression(Object, Keyword('fireAtTarget'), Array, Boolean),
    BinaryExpression(Object, Keyword('flyInHeight'), Number, Nothing),
    BinaryExpression(Object, Keyword('flyInHeightASL'), Array, Nothing),
    BinaryExpression(Code, Keyword('forEach'), Array, Nothing),
    BinaryExpression(Code, Keyword('forEachMember'), Object, Nothing),
    BinaryExpression(Code, Keyword('forEachMemberAgent'), Object, Nothing),
    BinaryExpression(Code, Keyword('forEachMemberTeam'), Object, Nothing),
    BinaryExpression(Object, Keyword('forceAddUniform'), String, Nothing),
    BinaryExpression(Object, Keyword('forceFollowRoad'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('forceSpeed'), Number, Nothing),
    BinaryExpression(Object, Keyword('forceWalk'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('forceWeaponFire'), Array, Nothing),
    BinaryExpression(ForType, Keyword('from'), Number, ForType),
    BinaryExpression(Object, Keyword('get3DENAttribute'), String, Array),
    BinaryExpression(Object, Keyword('get3DENAttribute'), String, Array),
    BinaryExpression(Array, Keyword('get3DENAttribute'), String, Array),
    BinaryExpression(String, Keyword('get3DENAttribute'), String, Array),
    BinaryExpression(Number, Keyword('get3DENAttribute'), String, Array),
    BinaryExpression(String, Keyword('get3DENMissionAttribute'), String, Nothing),
    BinaryExpression(Object, Keyword('getArtilleryETA'), Array, Number),
    BinaryExpression(Object, Keyword('getCargoIndex'), Object, Number),
    BinaryExpression(Object, Keyword('getDir'), Object, Number),
    BinaryExpression(Object, Keyword('getDir'), Array, Number),
    BinaryExpression(Array, Keyword('getDir'), Object, Number),
    BinaryExpression(Array, Keyword('getDir'), Array, Number),
    BinaryExpression(Object, Keyword('getEditorObjectScope'), String, String),
    BinaryExpression(Array, Keyword('getEnvSoundController'), String, Number),
    BinaryExpression(Number, Keyword('getFSMVariable'), String, Nothing),
    BinaryExpression(Number, Keyword('getFSMVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('getFriend'), Object, Number),
    BinaryExpression(Object, Keyword('getGroupIcon'), Number, Array),
    BinaryExpression(Object, Keyword('getHideFrom'), Object, Array),
    BinaryExpression(Object, Keyword('getHit'), String, Number),
    BinaryExpression(Object, Keyword('getHitIndex'), Number, Number),
    BinaryExpression(Object, Keyword('getHitPointDamage'), String, Number),
    BinaryExpression(Object, Keyword('getObjectArgument'), Array, String),
    BinaryExpression(Object, Keyword('getObjectChildren'), String, Array),
    BinaryExpression(Object, Keyword('getObjectProxy'), String, Object),
    BinaryExpression(Object, Keyword('getPos'), Array, Array),
    BinaryExpression(Array, Keyword('getPos'), Array, Array),
    BinaryExpression(Object, Keyword('getRelDir'), Object, Number),
    BinaryExpression(Object, Keyword('getRelDir'), Array, Number),
    BinaryExpression(Object, Keyword('getRelPos'), Array, Array),
    BinaryExpression(Object, Keyword('getSoundController'), String, Number),
    BinaryExpression(Object, Keyword('getSoundControllerResult'), Config, Number),
    BinaryExpression(Object, Keyword('getSpeed'), String, Number),
    BinaryExpression(Object, Keyword('getUnitTrait'), String, Nothing),
    BinaryExpression(Object, Keyword('getVariable'), String, Nothing),
    BinaryExpression(Object, Keyword('getVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('getVariable'), String, Nothing),
    BinaryExpression(Object, Keyword('getVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('getVariable'), String, Nothing),
    BinaryExpression(Object, Keyword('getVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('getVariable'), String, Nothing),
    BinaryExpression(Object, Keyword('getVariable'), Array, Nothing),
    BinaryExpression(Namespace, Keyword('getVariable'), String, Nothing),
    BinaryExpression(Namespace, Keyword('getVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('getVariable'), String, Nothing),
    BinaryExpression(Object, Keyword('getVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('getVariable'), String, Nothing),
    BinaryExpression(Object, Keyword('getVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('getVariable'), String, Nothing),
    BinaryExpression(Object, Keyword('getVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('glanceAt'), Object, Nothing),
    BinaryExpression(Object, Keyword('glanceAt'), Array, Nothing),
    BinaryExpression(Array, Keyword('glanceAt'), Object, Nothing),
    BinaryExpression(Array, Keyword('glanceAt'), Array, Nothing),
    BinaryExpression(Object, Keyword('globalChat'), String, Nothing),
    BinaryExpression(Object, Keyword('globalRadio'), String, Nothing),
    BinaryExpression(Object, Keyword('groupChat'), String, Nothing),
    BinaryExpression(Object, Keyword('groupRadio'), String, Nothing),
    BinaryExpression(Object, Keyword('groupSelectUnit'), Array, Nothing),
    BinaryExpression(Object, Keyword('hasWeapon'), String, Boolean),
    BinaryExpression(Object, Keyword('hcGroupParams'), Object, Array),
    BinaryExpression(Object, Keyword('hcRemoveGroup'), Object, Nothing),
    BinaryExpression(Object, Keyword('hcSelectGroup'), Array, Nothing),
    BinaryExpression(Object, Keyword('hcSetGroup'), Array, Nothing),
    BinaryExpression(Object, Keyword('hideObject'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('hideObjectGlobal'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('hideSelection'), Array, Nothing),
    BinaryExpression(String, Keyword('hintC'), String, Nothing),
    BinaryExpression(String, Keyword('hintC'), String, Nothing),
    BinaryExpression(String, Keyword('hintC'), Array, Nothing),
    BinaryExpression(Object, Keyword('htmlLoad'), String, Nothing),
    BinaryExpression(Type, Keyword('in'), Array, Boolean),
    BinaryExpression(Object, Keyword('in'), Object, Boolean),
    BinaryExpression(Array, Keyword('in'), Object, Boolean),
    BinaryExpression(Object, Keyword('inArea'), Object, Boolean),
    BinaryExpression(Array, Keyword('inArea'), Object, Boolean),
    BinaryExpression(Object, Keyword('inArea'), String, Boolean),
    BinaryExpression(Array, Keyword('inArea'), String, Boolean),
    BinaryExpression(Object, Keyword('inArea'), Array, Boolean),
    BinaryExpression(Array, Keyword('inArea'), Array, Boolean),
    BinaryExpression(Object, Keyword('inArea'), Object, Boolean),
    BinaryExpression(Array, Keyword('inArea'), Object, Boolean),
    BinaryExpression(Array, Keyword('inAreaArray'), Object, Array),
    BinaryExpression(Array, Keyword('inAreaArray'), String, Array),
    BinaryExpression(Array, Keyword('inAreaArray'), Array, Array),
    BinaryExpression(Array, Keyword('inAreaArray'), Object, Array),
    BinaryExpression(Array, Keyword('inPolygon'), Array, Boolean),
    BinaryExpression(Array, Keyword('inRangeOfArtillery'), Array, Boolean),
    BinaryExpression(Object, Keyword('inflame'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('insertEditorObject'), Array, String),
    BinaryExpression(Array, Keyword('intersect'), Array, Array),
    BinaryExpression(Type, Keyword('isEqualTo'), Type, Boolean),
    BinaryExpression(Type, Keyword('isEqualType'), Type, Boolean),
    BinaryExpression(Array, Keyword('isEqualTypeAll'), Type, Boolean),
    BinaryExpression(Type, Keyword('isEqualTypeAny'), Array, Boolean),
    BinaryExpression(Array, Keyword('isEqualTypeArray'), Array, Boolean),
    BinaryExpression(Type, Keyword('isEqualTypeParams'), Array, Boolean),
    BinaryExpression(Object, Keyword('isFlashlightOn'), String, Boolean),
    BinaryExpression(Array, Keyword('isFlatEmpty'), Array, Array),
    BinaryExpression(Object, Keyword('isIRLaserOn'), String, Boolean),
    BinaryExpression(String, Keyword('isKindOf'), String, Boolean),
    BinaryExpression(String, Keyword('isKindOf'), Array, Boolean),
    BinaryExpression(Object, Keyword('isKindOf'), String, Boolean),
    BinaryExpression(Object, Keyword('isUAVConnectable'), Array, Boolean),
    BinaryExpression(Object, Keyword('isUniformAllowed'), String, Boolean),
    BinaryExpression(Array, Keyword('join'), Object, Nothing),
    BinaryExpression(Array, Keyword('join'), Object, Nothing),
    BinaryExpression(Object, Keyword('joinAs'), Array, Nothing),
    BinaryExpression(Object, Keyword('joinAsSilent'), Array, Nothing),
    BinaryExpression(Array, Keyword('joinSilent'), Object, Nothing),
    BinaryExpression(Array, Keyword('joinSilent'), Object, Nothing),
    BinaryExpression(Array, Keyword('joinString'), String, String),
    BinaryExpression(Object, Keyword('kbAddDatabase'), String, Boolean),
    BinaryExpression(Object, Keyword('kbAddDatabaseTargets'), String, Boolean),
    BinaryExpression(Object, Keyword('kbAddTopic'), Array, Nothing),
    BinaryExpression(Object, Keyword('kbHasTopic'), String, Boolean),
    BinaryExpression(Object, Keyword('kbReact'), Array, Nothing),
    BinaryExpression(Object, Keyword('kbRemoveTopic'), String, Nothing),
    BinaryExpression(Object, Keyword('kbTell'), Array, Nothing),
    BinaryExpression(Object, Keyword('kbWasSaid'), Array, Boolean),
    BinaryExpression(Object, Keyword('knowsAbout'), Object, Number),
    BinaryExpression(Object, Keyword('knowsAbout'), Object, Number),
    BinaryExpression(Object, Keyword('knowsAbout'), Object, Number),
    BinaryExpression(Object, Keyword('land'), String, Nothing),
    BinaryExpression(Object, Keyword('landAt'), Object, Nothing),
    BinaryExpression(Object, Keyword('landAt'), Number, Nothing),
    BinaryExpression(Object, Keyword('lbAdd'), String, Number),
    BinaryExpression(Object, Keyword('lbColor'), Number, Array),
    BinaryExpression(Object, Keyword('lbColorRight'), Number, Array),
    BinaryExpression(Object, Keyword('lbData'), Number, String),
    BinaryExpression(Object, Keyword('lbDelete'), Number, Nothing),
    BinaryExpression(Object, Keyword('lbIsSelected'), Number, Boolean),
    BinaryExpression(Object, Keyword('lbPicture'), Number, String),
    BinaryExpression(Object, Keyword('lbPictureRight'), Number, String),
    BinaryExpression(Object, Keyword('lbSetColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetColorRight'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetCurSel'), Number, Nothing),
    BinaryExpression(Object, Keyword('lbSetData'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetPicture'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetPictureColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetPictureColorDisabled'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetPictureColorSelected'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetPictureRight'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetPictureRightColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetPictureRightColorDisabled'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetPictureRightColorSelected'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetSelectColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetSelectColorRight'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetSelected'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetText'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetTextRight'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetTooltip'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbSetValue'), Array, Nothing),
    BinaryExpression(Object, Keyword('lbText'), Number, String),
    BinaryExpression(Object, Keyword('lbTextRight'), Number, String),
    BinaryExpression(Object, Keyword('lbValue'), Number, Number),
    BinaryExpression(Object, Keyword('leaveVehicle'), Object, Nothing),
    BinaryExpression(Object, Keyword('leaveVehicle'), Object, Nothing),
    BinaryExpression(Object, Keyword('lightAttachObject'), Array, Nothing),
    BinaryExpression(Object, Keyword('limitSpeed'), Number, Nothing),
    BinaryExpression(Object, Keyword('linkItem'), String, Nothing),
    BinaryExpression(Object, Keyword('listObjects'), String, Array),
    BinaryExpression(Object, Keyword('lnbAddColumn'), Number, Number),
    BinaryExpression(Object, Keyword('lnbAddRow'), Array, Number),
    BinaryExpression(Object, Keyword('lnbColor'), Array, Array),
    BinaryExpression(Object, Keyword('lnbColorRight'), Array, Array),
    BinaryExpression(Object, Keyword('lnbData'), Array, String),
    BinaryExpression(Object, Keyword('lnbDeleteColumn'), Number, Nothing),
    BinaryExpression(Object, Keyword('lnbDeleteRow'), Number, Nothing),
    BinaryExpression(Object, Keyword('lnbPicture'), Array, String),
    BinaryExpression(Object, Keyword('lnbPictureRight'), Array, String),
    BinaryExpression(Object, Keyword('lnbSetColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('lnbSetColorRight'), Array, Nothing),
    BinaryExpression(Object, Keyword('lnbSetColumnsPos'), Array, Nothing),
    BinaryExpression(Object, Keyword('lnbSetCurSelRow'), Number, Nothing),
    BinaryExpression(Object, Keyword('lnbSetData'), Array, Nothing),
    BinaryExpression(Object, Keyword('lnbSetPicture'), Array, Nothing),
    BinaryExpression(Object, Keyword('lnbSetPictureColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('lnbSetPictureColorRight'), Array, Nothing),
    BinaryExpression(Object, Keyword('lnbSetPictureColorSelected'), Array, Nothing),
    BinaryExpression(Object, Keyword('lnbSetPictureColorSelectedRight'), Array, Nothing),
    BinaryExpression(Object, Keyword('lnbSetPictureRight'), Array, Nothing),
    BinaryExpression(Object, Keyword('lnbSetText'), Array, Nothing),
    BinaryExpression(Object, Keyword('lnbSetTextRight'), Array, Nothing),
    BinaryExpression(Object, Keyword('lnbSetValue'), Array, Nothing),
    BinaryExpression(Object, Keyword('lnbSort'), Array, Nothing),
    BinaryExpression(Object, Keyword('lnbSortByValue'), Array, Nothing),
    BinaryExpression(Object, Keyword('lnbText'), Array, String),
    BinaryExpression(Object, Keyword('lnbTextRight'), Array, String),
    BinaryExpression(Object, Keyword('lnbValue'), Array, Number),
    BinaryExpression(Object, Keyword('loadIdentity'), String, Boolean),
    BinaryExpression(Object, Keyword('loadMagazine'), Array, Nothing),
    BinaryExpression(Object, Keyword('loadOverlay'), Config, Nothing),
    BinaryExpression(Object, Keyword('loadStatus'), String, Boolean),
    BinaryExpression(Object, Keyword('lock'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('lock'), Number, Nothing),
    BinaryExpression(Object, Keyword('lockCameraTo'), Array, Nothing),
    BinaryExpression(Object, Keyword('lockCargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('lockCargo'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('lockDriver'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('lockTurret'), Array, Nothing),
    BinaryExpression(Object, Keyword('lockWp'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('lockWp'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('lockedCargo'), Number, Boolean),
    BinaryExpression(Object, Keyword('lockedTurret'), Array, Boolean),
    BinaryExpression(Object, Keyword('lookAt'), Object, Nothing),
    BinaryExpression(Object, Keyword('lookAt'), Array, Nothing),
    BinaryExpression(Array, Keyword('lookAt'), Object, Nothing),
    BinaryExpression(Array, Keyword('lookAt'), Array, Nothing),
    BinaryExpression(Object, Keyword('lookAtPos'), Array, Nothing),
    BinaryExpression(Object, Keyword('magazineTurretAmmo'), Array, Number),
    BinaryExpression(Object, Keyword('magazinesTurret'), Array, Array),
    BinaryExpression(Object, Keyword('mapCenterOnCamera'), Boolean, Nothing),
    BinaryExpression(Number, Keyword('max'), Number, Number),
    BinaryExpression(Object, Keyword('menuAction'), Array, String),
    BinaryExpression(Object, Keyword('menuAdd'), Array, Number),
    BinaryExpression(Object, Keyword('menuChecked'), Array, Boolean),
    BinaryExpression(Object, Keyword('menuCollapse'), Array, Nothing),
    BinaryExpression(Object, Keyword('menuData'), Array, String),
    BinaryExpression(Object, Keyword('menuDelete'), Array, Nothing),
    BinaryExpression(Object, Keyword('menuEnable'), Array, Nothing),
    BinaryExpression(Object, Keyword('menuEnabled'), Array, Boolean),
    BinaryExpression(Object, Keyword('menuExpand'), Array, Nothing),
    BinaryExpression(Object, Keyword('menuPicture'), Array, String),
    BinaryExpression(Object, Keyword('menuSetAction'), Array, Nothing),
    BinaryExpression(Object, Keyword('menuSetCheck'), Array, Nothing),
    BinaryExpression(Object, Keyword('menuSetData'), Array, Nothing),
    BinaryExpression(Object, Keyword('menuSetPicture'), Array, Nothing),
    BinaryExpression(Object, Keyword('menuSetValue'), Array, Nothing),
    BinaryExpression(Object, Keyword('menuShortcut'), Array, Number),
    BinaryExpression(Object, Keyword('menuShortcutText'), Array, String),
    BinaryExpression(Object, Keyword('menuSize'), Array, Number),
    BinaryExpression(Object, Keyword('menuSort'), Array, Nothing),
    BinaryExpression(Object, Keyword('menuText'), Array, String),
    BinaryExpression(Object, Keyword('menuURL'), Array, String),
    BinaryExpression(Object, Keyword('menuValue'), Array, Number),
    BinaryExpression(Number, Keyword('min'), Number, Number),
    BinaryExpression(Object, Keyword('mineDetectedBy'), Object, Boolean),
    BinaryExpression(Number, Keyword('mod'), Number, Number),
    BinaryExpression(Object, Keyword('modelToWorld'), Array, Array),
    BinaryExpression(Object, Keyword('modelToWorldVisual'), Array, Array),
    BinaryExpression(Object, Keyword('move'), Array, Nothing),
    BinaryExpression(Object, Keyword('move'), Array, Nothing),
    BinaryExpression(Object, Keyword('moveInAny'), Object, Boolean),
    BinaryExpression(Object, Keyword('moveInCargo'), Object, Nothing),
    BinaryExpression(Object, Keyword('moveInCargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('moveInCommander'), Object, Nothing),
    BinaryExpression(Object, Keyword('moveInDriver'), Object, Nothing),
    BinaryExpression(Object, Keyword('moveInGunner'), Object, Nothing),
    BinaryExpression(Object, Keyword('moveInTurret'), Array, Nothing),
    BinaryExpression(Object, Keyword('moveObjectToEnd'), String, Nothing),
    BinaryExpression(Object, Keyword('moveTo'), Array, Nothing),
    BinaryExpression(Object, Keyword('nMenuItems'), String, Number),
    BinaryExpression(Object, Keyword('nMenuItems'), Number, Number),
    BinaryExpression(Object, Keyword('nearEntities'), Number, Array),
    BinaryExpression(Object, Keyword('nearEntities'), Array, Array),
    BinaryExpression(Array, Keyword('nearEntities'), Number, Array),
    BinaryExpression(Array, Keyword('nearEntities'), Array, Array),
    BinaryExpression(Object, Keyword('nearObjects'), Number, Array),
    BinaryExpression(Object, Keyword('nearObjects'), Array, Array),
    BinaryExpression(Array, Keyword('nearObjects'), Number, Array),
    BinaryExpression(Array, Keyword('nearObjects'), Array, Array),
    BinaryExpression(Object, Keyword('nearObjectsReady'), Number, Boolean),
    BinaryExpression(Array, Keyword('nearObjectsReady'), Number, Boolean),
    BinaryExpression(Object, Keyword('nearRoads'), Number, Array),
    BinaryExpression(Array, Keyword('nearRoads'), Number, Array),
    BinaryExpression(Object, Keyword('nearSupplies'), Number, Array),
    BinaryExpression(Object, Keyword('nearSupplies'), Array, Array),
    BinaryExpression(Array, Keyword('nearSupplies'), Number, Array),
    BinaryExpression(Array, Keyword('nearSupplies'), Array, Array),
    BinaryExpression(Object, Keyword('nearTargets'), Number, Array),
    BinaryExpression(Array, Keyword('nearestObject'), String, Object),
    BinaryExpression(Array, Keyword('nearestObject'), Number, Object),
    BinaryExpression(Object, Keyword('newOverlay'), Config, Nothing),
    BinaryExpression(String, Keyword('objStatus'), String, Nothing),
    BinaryExpression(Object, Keyword('onDoubleClick'), String, Nothing),
    BinaryExpression(Type, Keyword('onMapSingleClick'), Code, Nothing),
    BinaryExpression(Type, Keyword('onMapSingleClick'), String, Nothing),
    BinaryExpression(Object, Keyword('onShowNewObject'), String, Nothing),
    BinaryExpression(Boolean, Keyword('or'), Boolean, Boolean),
    BinaryExpression(Boolean, Keyword('or'), Code, Boolean),
    BinaryExpression(Array, Keyword('orderGetIn'), Boolean, Nothing),
    BinaryExpression(Type, Keyword('param'), Array, Nothing),
    BinaryExpression(Type, Keyword('params'), Array, Boolean),
    BinaryExpression(Object, Keyword('playAction'), String, Nothing),
    BinaryExpression(Object, Keyword('playActionNow'), String, Nothing),
    BinaryExpression(Object, Keyword('playGesture'), String, Nothing),
    BinaryExpression(Object, Keyword('playMove'), String, Nothing),
    BinaryExpression(Object, Keyword('playMoveNow'), String, Nothing),
    BinaryExpression(Object, Keyword('posScreenToWorld'), Array, Array),
    BinaryExpression(Object, Keyword('posWorldToScreen'), Array, Array),
    BinaryExpression(String, Keyword('ppEffectAdjust'), Array, Nothing),
    BinaryExpression(Number, Keyword('ppEffectAdjust'), Array, Nothing),
    BinaryExpression(String, Keyword('ppEffectCommit'), Number, Nothing),
    BinaryExpression(Number, Keyword('ppEffectCommit'), Number, Nothing),
    BinaryExpression(Array, Keyword('ppEffectCommit'), Number, Nothing),
    BinaryExpression(String, Keyword('ppEffectEnable'), Boolean, Nothing),
    BinaryExpression(Array, Keyword('ppEffectEnable'), Boolean, Nothing),
    BinaryExpression(Number, Keyword('ppEffectEnable'), Boolean, Nothing),
    BinaryExpression(Number, Keyword('ppEffectForceInNVG'), Boolean, Nothing),
    BinaryExpression(Number, Keyword('preloadObject'), Object, Boolean),
    BinaryExpression(Number, Keyword('preloadObject'), String, Boolean),
    BinaryExpression(Object, Keyword('progressSetPosition'), Number, Nothing),
    BinaryExpression(Number, Keyword('publicVariableClient'), String, Nothing),
    BinaryExpression(Array, Keyword('pushBack'), Type, Number),
    BinaryExpression(Array, Keyword('pushBackUnique'), Type, Number),
    BinaryExpression(Number, Keyword('radioChannelAdd'), Array, Nothing),
    BinaryExpression(Number, Keyword('radioChannelRemove'), Array, Nothing),
    BinaryExpression(Number, Keyword('radioChannelSetCallSign'), String, Nothing),
    BinaryExpression(Number, Keyword('radioChannelSetLabel'), String, Nothing),
    BinaryExpression(Number, Keyword('random'), Number, Number),
    BinaryExpression(Number, Keyword('random'), Array, Number),
    BinaryExpression(Object, Keyword('registerTask'), String, Boolean),
    BinaryExpression(Object, Keyword('remoteControl'), Object, Nothing),
    BinaryExpression(Type, Keyword('remoteExec'), Array, Nothing),
    BinaryExpression(Type, Keyword('remoteExecCall'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeAction'), Number, Nothing),
    BinaryExpression(Object, Keyword('removeAllEventHandlers'), String, Nothing),
    BinaryExpression(Object, Keyword('removeAllMPEventHandlers'), String, Nothing),
    BinaryExpression(Object, Keyword('removeCuratorAddons'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeCuratorCameraArea'), Number, Nothing),
    BinaryExpression(Object, Keyword('removeCuratorEditableObjects'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeCuratorEditingArea'), Number, Nothing),
    BinaryExpression(Object, Keyword('removeDrawIcon'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeDrawLinks'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeEventHandler'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeGroupIcon'), Number, Nothing),
    BinaryExpression(Object, Keyword('removeHandgunItem'), String, Nothing),
    BinaryExpression(Object, Keyword('removeItem'), String, Nothing),
    BinaryExpression(Object, Keyword('removeItemFromBackpack'), String, Nothing),
    BinaryExpression(Object, Keyword('removeItemFromUniform'), String, Nothing),
    BinaryExpression(Object, Keyword('removeItemFromVest'), String, Nothing),
    BinaryExpression(Object, Keyword('removeItems'), String, Nothing),
    BinaryExpression(Object, Keyword('removeMPEventHandler'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeMagazine'), String, Nothing),
    BinaryExpression(Object, Keyword('removeMagazine'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeMagazineGlobal'), String, Nothing),
    BinaryExpression(Object, Keyword('removeMagazineTurret'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeMagazines'), String, Nothing),
    BinaryExpression(Object, Keyword('removeMagazinesTurret'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeMenuItem'), Number, Nothing),
    BinaryExpression(Object, Keyword('removeMenuItem'), String, Nothing),
    BinaryExpression(Object, Keyword('removeOwnedMine'), Object, Nothing),
    BinaryExpression(Object, Keyword('removePrimaryWeaponItem'), String, Nothing),
    BinaryExpression(Object, Keyword('removeSecondaryWeaponItem'), String, Nothing),
    BinaryExpression(Object, Keyword('removeSimpleTask'), Object, Nothing),
    BinaryExpression(Object, Keyword('removeTeamMember'), Object, Nothing),
    BinaryExpression(Object, Keyword('removeWeapon'), String, Nothing),
    BinaryExpression(Object, Keyword('removeWeaponAttachmentCargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeWeaponCargo'), Array, Nothing),
    BinaryExpression(Object, Keyword('removeWeaponGlobal'), String, Nothing),
    BinaryExpression(Object, Keyword('removeWeaponTurret'), Array, Nothing),
    BinaryExpression(Array, Keyword('resize'), Number, Nothing),
    BinaryExpression(Object, Keyword('respawnVehicle'), Array, Nothing),
    BinaryExpression(Object, Keyword('reveal'), Object, Nothing),
    BinaryExpression(Object, Keyword('reveal'), Object, Nothing),
    BinaryExpression(Object, Keyword('reveal'), Array, Nothing),
    BinaryExpression(Object, Keyword('reveal'), Array, Nothing),
    BinaryExpression(Object, Keyword('revealMine'), Object, Nothing),
    BinaryExpression(Array, Keyword('ropeAttachTo'), Object, Nothing),
    BinaryExpression(Object, Keyword('ropeDetach'), Object, Nothing),
    BinaryExpression(Object, Keyword('saveIdentity'), String, Boolean),
    BinaryExpression(Object, Keyword('saveStatus'), String, Boolean),
    BinaryExpression(Object, Keyword('say'), String, Nothing),
    BinaryExpression(Array, Keyword('say'), String, Nothing),
    BinaryExpression(Object, Keyword('say'), Array, Nothing),
    BinaryExpression(Array, Keyword('say'), Array, Nothing),
    BinaryExpression(Object, Keyword('say2D'), String, Nothing),
    BinaryExpression(Array, Keyword('say2D'), String, Nothing),
    BinaryExpression(Object, Keyword('say2D'), Array, Nothing),
    BinaryExpression(Array, Keyword('say2D'), Array, Nothing),
    BinaryExpression(Object, Keyword('say3D'), String, Nothing),
    BinaryExpression(Array, Keyword('say3D'), String, Nothing),
    BinaryExpression(Object, Keyword('say3D'), Array, Nothing),
    BinaryExpression(Array, Keyword('say3D'), Array, Nothing),
    BinaryExpression(Array, Keyword('select'), Number, Nothing),
    BinaryExpression(Array, Keyword('select'), Boolean, Nothing),
    BinaryExpression(Array, Keyword('select'), Array, Array),
    BinaryExpression(String, Keyword('select'), Array, String),
    BinaryExpression(Array, Keyword('select'), Code, Array),
    BinaryExpression(Config, Keyword('select'), Number, Config),
    BinaryExpression(Object, Keyword('selectDiarySubject'), String, Nothing),
    BinaryExpression(Object, Keyword('selectEditorObject'), String, Nothing),
    BinaryExpression(Object, Keyword('selectLeader'), Object, Nothing),
    BinaryExpression(Object, Keyword('selectWeapon'), String, Nothing),
    BinaryExpression(Object, Keyword('selectWeaponTurret'), Array, Nothing),
    BinaryExpression(Object, Keyword('selectionPosition'), String, Array),
    BinaryExpression(Object, Keyword('selectionPosition'), Array, Array),
    BinaryExpression(Object, Keyword('sendSimpleCommand'), String, Nothing),
    BinaryExpression(Object, Keyword('sendTask'), Array, Object),
    BinaryExpression(Object, Keyword('sendTaskResult'), Array, Nothing),
    BinaryExpression(String, Keyword('serverCommand'), String, Boolean),
    BinaryExpression(Array, Keyword('set'), Array, Nothing),
    BinaryExpression(Type, Keyword('set3DENAttribute'), Array, Boolean),
    BinaryExpression(Type, Keyword('set3DENLayer'), Number, Boolean),
    BinaryExpression(String, Keyword('set3DENMissionAttribute'), Array, Nothing),
    BinaryExpression(Array, Keyword('set3DENObjectType'), String, Nothing),
    BinaryExpression(Object, Keyword('setActualCollectiveRTD'), Number, Nothing),
    BinaryExpression(Object, Keyword('setAirportSide'), Object, Nothing),
    BinaryExpression(Number, Keyword('setAirportSide'), Object, Nothing),
    BinaryExpression(Object, Keyword('setAmmo'), Array, Nothing),
    BinaryExpression(Object, Keyword('setAmmoCargo'), Number, Nothing),
    BinaryExpression(Object, Keyword('setAnimSpeedCoef'), Number, Nothing),
    BinaryExpression(String, Keyword('setAttributes'), Array, String),
    BinaryExpression(String, Keyword('setAttributes'), Array, String),
    BinaryExpression(Object, Keyword('setAutonomous'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setBehaviour'), String, Nothing),
    BinaryExpression(Object, Keyword('setBehaviour'), String, Nothing),
    BinaryExpression(Object, Keyword('setBleedingRemaining'), Number, Nothing),
    BinaryExpression(Object, Keyword('setBrakesRTD'), Array, Nothing),
    BinaryExpression(Boolean, Keyword('setCamUseTi'), Number, Nothing),
    BinaryExpression(Object, Keyword('setCameraInterest'), Number, Nothing),
    BinaryExpression(Object, Keyword('setCaptive'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setCaptive'), Number, Nothing),
    BinaryExpression(Object, Keyword('setCenterOfMass'), Array, Nothing),
    BinaryExpression(Object, Keyword('setCollisionLight'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setCombatMode'), String, Nothing),
    BinaryExpression(Object, Keyword('setCombatMode'), String, Nothing),
    BinaryExpression(Object, Keyword('setCombatMode'), String, Nothing),
    BinaryExpression(Object, Keyword('setConvoySeparation'), Number, Nothing),
    BinaryExpression(Object, Keyword('setCuratorCameraAreaCeiling'), Number, Nothing),
    BinaryExpression(Object, Keyword('setCuratorCoef'), Array, Nothing),
    BinaryExpression(Object, Keyword('setCuratorEditingAreaType'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setCuratorWaypointCost'), Number, Nothing),
    BinaryExpression(Object, Keyword('setCurrentTask'), Object, Nothing),
    BinaryExpression(Object, Keyword('setCurrentWaypoint'), Array, Nothing),
    BinaryExpression(Object, Keyword('setCustomAimCoef'), Number, Nothing),
    BinaryExpression(Object, Keyword('setCustomWeightRTD'), Number, Nothing),
    BinaryExpression(Object, Keyword('setDamage'), Number, Nothing),
    BinaryExpression(Object, Keyword('setDamage'), Array, Nothing),
    BinaryExpression(Object, Keyword('setDammage'), Number, Nothing),
    BinaryExpression(String, Keyword('setDebriefingText'), Array, Nothing),
    BinaryExpression(Object, Keyword('setDestination'), Array, Nothing),
    BinaryExpression(Object, Keyword('setDir'), Number, Nothing),
    BinaryExpression(Object, Keyword('setDirection'), Number, Nothing),
    BinaryExpression(Object, Keyword('setDrawIcon'), Array, Nothing),
    BinaryExpression(Object, Keyword('setDriveOnPath'), Array, Nothing),
    BinaryExpression(Object, Keyword('setDropInterval'), Number, Nothing),
    BinaryExpression(String, Keyword('setDynamicSimulationDistance'), Number, Nothing),
    BinaryExpression(String, Keyword('setDynamicSimulationDistanceCoef'), Number, Nothing),
    BinaryExpression(Object, Keyword('setEditorMode'), String, Nothing),
    BinaryExpression(Object, Keyword('setEditorObjectScope'), Array, Nothing),
    BinaryExpression(Object, Keyword('setEffectCondition'), String, Nothing),
    BinaryExpression(Array, Keyword('setEffectCondition'), String, Nothing),
    BinaryExpression(Object, Keyword('setEngineRpmRTD'), Array, Nothing),
    BinaryExpression(Number, Keyword('setFSMVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('setFace'), String, Nothing),
    BinaryExpression(Object, Keyword('setFaceanimation'), Number, Nothing),
    BinaryExpression(Object, Keyword('setFatigue'), Number, Nothing),
    BinaryExpression(Object, Keyword('setFeatureType'), Number, Boolean),
    BinaryExpression(Object, Keyword('setFlagAnimationPhase'), Number, Nothing),
    BinaryExpression(Object, Keyword('setFlagOwner'), Object, Nothing),
    BinaryExpression(Object, Keyword('setFlagSide'), Object, Nothing),
    BinaryExpression(Object, Keyword('setFlagTexture'), String, Nothing),
    BinaryExpression(Number, Keyword('setFog'), Number, Nothing),
    BinaryExpression(Number, Keyword('setFog'), Array, Nothing),
    BinaryExpression(Number, Keyword('setForceGeneratorRTD'), Array, Nothing),
    BinaryExpression(Object, Keyword('setFormDir'), Number, Nothing),
    BinaryExpression(Object, Keyword('setFormDir'), Number, Nothing),
    BinaryExpression(Object, Keyword('setFormation'), String, Nothing),
    BinaryExpression(Object, Keyword('setFormation'), String, Nothing),
    BinaryExpression(Object, Keyword('setFormation'), String, Nothing),
    BinaryExpression(Object, Keyword('setFormationTask'), String, Nothing),
    BinaryExpression(Object, Keyword('setFriend'), Array, Nothing),
    BinaryExpression(Object, Keyword('setFromEditor'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setFuel'), Number, Nothing),
    BinaryExpression(Object, Keyword('setFuelCargo'), Number, Nothing),
    BinaryExpression(Object, Keyword('setGroupIcon'), Array, Nothing),
    BinaryExpression(Object, Keyword('setGroupIconParams'), Array, Nothing),
    BinaryExpression(Object, Keyword('setGroupIdGlobal'), Array, Nothing),
    BinaryExpression(Object, Keyword('setGroupIdGlobal'), Array, Nothing),
    BinaryExpression(Object, Keyword('setGroupOwner'), Number, Boolean),
    BinaryExpression(Object, Keyword('setGroupid'), Array, Nothing),
    BinaryExpression(Object, Keyword('setGroupid'), Array, Nothing),
    BinaryExpression(Number, Keyword('setGusts'), Number, Nothing),
    BinaryExpression(Object, Keyword('setHideBehind'), Array, Nothing),
    BinaryExpression(Object, Keyword('setHit'), Array, Nothing),
    BinaryExpression(Object, Keyword('setHitIndex'), Array, Nothing),
    BinaryExpression(Object, Keyword('setHitPointDamage'), Array, Nothing),
    BinaryExpression(Object, Keyword('setIdentity'), String, Nothing),
    BinaryExpression(Object, Keyword('setImportance'), Number, Nothing),
    BinaryExpression(Object, Keyword('setLeader'), Object, Nothing),
    BinaryExpression(Object, Keyword('setLightAmbient'), Array, Nothing),
    BinaryExpression(Object, Keyword('setLightAttenuation'), Array, Nothing),
    BinaryExpression(Object, Keyword('setLightBrightness'), Number, Nothing),
    BinaryExpression(Object, Keyword('setLightColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('setLightDayLight'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setLightFlareMaxDistance'), Number, Nothing),
    BinaryExpression(Object, Keyword('setLightFlareSize'), Number, Nothing),
    BinaryExpression(Object, Keyword('setLightIntensity'), Number, Nothing),
    BinaryExpression(Object, Keyword('setLightUseFlare'), Boolean, Nothing),
    BinaryExpression(Number, Keyword('setLightnings'), Number, Nothing),
    BinaryExpression(Object, Keyword('setMagazineTurretAmmo'), Array, Nothing),
    BinaryExpression(String, Keyword('setMarkerAlpha'), Number, Nothing),
    BinaryExpression(String, Keyword('setMarkerAlphaLocal'), Number, Nothing),
    BinaryExpression(String, Keyword('setMarkerBrush'), String, Nothing),
    BinaryExpression(String, Keyword('setMarkerBrushLocal'), String, Nothing),
    BinaryExpression(String, Keyword('setMarkerColor'), String, Nothing),
    BinaryExpression(String, Keyword('setMarkerColorLocal'), String, Nothing),
    BinaryExpression(String, Keyword('setMarkerDir'), Number, Nothing),
    BinaryExpression(String, Keyword('setMarkerDirLocal'), Number, Nothing),
    BinaryExpression(String, Keyword('setMarkerPos'), Array, Nothing),
    BinaryExpression(String, Keyword('setMarkerPosLocal'), Array, Nothing),
    BinaryExpression(String, Keyword('setMarkerShape'), String, Nothing),
    BinaryExpression(String, Keyword('setMarkerShapeLocal'), String, Nothing),
    BinaryExpression(String, Keyword('setMarkerSize'), Array, Nothing),
    BinaryExpression(String, Keyword('setMarkerSizeLocal'), Array, Nothing),
    BinaryExpression(String, Keyword('setMarkerText'), String, Nothing),
    BinaryExpression(String, Keyword('setMarkerTextLocal'), String, Nothing),
    BinaryExpression(String, Keyword('setMarkerType'), String, Nothing),
    BinaryExpression(String, Keyword('setMarkerTypeLocal'), String, Nothing),
    BinaryExpression(Object, Keyword('setMass'), Number, Nothing),
    BinaryExpression(Object, Keyword('setMass'), Array, Nothing),
    BinaryExpression(Object, Keyword('setMimic'), String, Nothing),
    BinaryExpression(Object, Keyword('setMusicEffect'), String, Nothing),
    BinaryExpression(Array, Keyword('setMusicEffect'), String, Nothing),
    BinaryExpression(Object, Keyword('setName'), String, Nothing),
    BinaryExpression(Object, Keyword('setName'), Array, Nothing),
    BinaryExpression(Object, Keyword('setName'), String, Nothing),
    BinaryExpression(Object, Keyword('setNameSound'), String, Nothing),
    BinaryExpression(Object, Keyword('setObjectArguments'), Array, Nothing),
    BinaryExpression(Object, Keyword('setObjectMaterial'), Array, Nothing),
    BinaryExpression(Object, Keyword('setObjectMaterialGlobal'), Array, Nothing),
    BinaryExpression(Object, Keyword('setObjectProxy'), Array, Nothing),
    BinaryExpression(Object, Keyword('setObjectTexture'), Array, Nothing),
    BinaryExpression(Object, Keyword('setObjectTextureGlobal'), Array, Nothing),
    BinaryExpression(Number, Keyword('setOvercast'), Number, Nothing),
    BinaryExpression(Object, Keyword('setOwner'), Number, Boolean),
    BinaryExpression(Object, Keyword('setOxygenRemaining'), Number, Nothing),
    BinaryExpression(Object, Keyword('setParticleCircle'), Array, Nothing),
    BinaryExpression(Object, Keyword('setParticleClass'), String, Nothing),
    BinaryExpression(Object, Keyword('setParticleFire'), Array, Nothing),
    BinaryExpression(Object, Keyword('setParticleParams'), Array, Nothing),
    BinaryExpression(Object, Keyword('setParticleRandom'), Array, Nothing),
    BinaryExpression(String, Keyword('setPiPEffect'), Array, Nothing),
    BinaryExpression(Object, Keyword('setPilotCameraDirection'), Array, Nothing),
    BinaryExpression(Object, Keyword('setPilotCameraRotation'), Array, Nothing),
    BinaryExpression(Object, Keyword('setPilotCameraTarget'), Object, Boolean),
    BinaryExpression(Object, Keyword('setPilotCameraTarget'), Array, Boolean),
    BinaryExpression(Object, Keyword('setPilotLight'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setPitch'), Number, Nothing),
    BinaryExpression(Object, Keyword('setPos'), Array, Nothing),
    BinaryExpression(Object, Keyword('setPosASL'), Array, Nothing),
    BinaryExpression(Object, Keyword('setPosASL2'), Array, Nothing),
    BinaryExpression(Object, Keyword('setPosASLW'), Array, Nothing),
    BinaryExpression(Object, Keyword('setPosATL'), Array, Nothing),
    BinaryExpression(Object, Keyword('setPosWorld'), Array, Nothing),
    BinaryExpression(Object, Keyword('setPosition'), Array, Nothing),
    BinaryExpression(Number, Keyword('setRadioMsg'), String, Nothing),
    BinaryExpression(Number, Keyword('setRain'), Number, Nothing),
    BinaryExpression(Number, Keyword('setRainbow'), Number, Nothing),
    BinaryExpression(Object, Keyword('setRandomLip'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setRank'), String, Nothing),
    BinaryExpression(Object, Keyword('setRectangular'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setRepairCargo'), Number, Nothing),
    BinaryExpression(Object, Keyword('setRotorBrakeRTD'), Number, Nothing),
    BinaryExpression(Object, Keyword('setShotParents'), Array, Nothing),
    BinaryExpression(Object, Keyword('setSide'), Object, Nothing),
    BinaryExpression(Object, Keyword('setSimpleTaskAlwaysVisible'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setSimpleTaskCustomData'), Array, Nothing),
    BinaryExpression(Object, Keyword('setSimpleTaskDescription'), Array, Nothing),
    BinaryExpression(Object, Keyword('setSimpleTaskDestination'), Array, Nothing),
    BinaryExpression(Object, Keyword('setSimpleTaskTarget'), Array, Nothing),
    BinaryExpression(Object, Keyword('setSimpleTaskType'), String, Nothing),
    BinaryExpression(Object, Keyword('setSize'), Array, Nothing),
    BinaryExpression(Object, Keyword('setSkill'), Array, Nothing),
    BinaryExpression(Object, Keyword('setSkill'), Number, Nothing),
    BinaryExpression(Object, Keyword('setSlingLoad'), Object, Boolean),
    BinaryExpression(Object, Keyword('setSoundEffect'), Array, Nothing),
    BinaryExpression(Array, Keyword('setSoundEffect'), Array, Nothing),
    BinaryExpression(Object, Keyword('setSpeaker'), String, Nothing),
    BinaryExpression(Object, Keyword('setSpeech'), String, Nothing),
    BinaryExpression(Object, Keyword('setSpeedMode'), String, Nothing),
    BinaryExpression(Object, Keyword('setSpeedMode'), String, Nothing),
    BinaryExpression(Object, Keyword('setStamina'), Number, Nothing),
    BinaryExpression(Object, Keyword('setSuppression'), Number, Nothing),
    BinaryExpression(Object, Keyword('setTargetAge'), String, Nothing),
    BinaryExpression(Object, Keyword('setTaskMarkerOffset'), Array, Nothing),
    BinaryExpression(Object, Keyword('setTaskResult'), Array, Nothing),
    BinaryExpression(Object, Keyword('setTaskState'), String, Nothing),
    BinaryExpression(Object, Keyword('setText'), String, Nothing),
    BinaryExpression(Object, Keyword('setTitleEffect'), Array, Nothing),
    BinaryExpression(Array, Keyword('setTitleEffect'), Array, Nothing),
    BinaryExpression(Object, Keyword('setTriggerActivation'), Array, Nothing),
    BinaryExpression(Object, Keyword('setTriggerArea'), Array, Nothing),
    BinaryExpression(Object, Keyword('setTriggerStatements'), Array, Nothing),
    BinaryExpression(Object, Keyword('setTriggerText'), String, Nothing),
    BinaryExpression(Object, Keyword('setTriggerTimeout'), Array, Nothing),
    BinaryExpression(Object, Keyword('setTriggerType'), String, Nothing),
    BinaryExpression(Object, Keyword('setType'), String, Nothing),
    BinaryExpression(Object, Keyword('setUnconscious'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setUnitAbility'), Number, Nothing),
    BinaryExpression(Object, Keyword('setUnitLoadout'), Array, Nothing),
    BinaryExpression(Object, Keyword('setUnitLoadout'), String, Nothing),
    BinaryExpression(Object, Keyword('setUnitLoadout'), Config, Nothing),
    BinaryExpression(Object, Keyword('setUnitPos'), String, Nothing),
    BinaryExpression(Object, Keyword('setUnitPosWeak'), String, Nothing),
    BinaryExpression(Object, Keyword('setUnitRank'), String, Nothing),
    BinaryExpression(Object, Keyword('setUnitRecoilCoefficient'), Number, Nothing),
    BinaryExpression(Object, Keyword('setUnitTrait'), Array, Nothing),
    BinaryExpression(Object, Keyword('setUnloadInCombat'), Array, Nothing),
    BinaryExpression(Object, Keyword('setUserActionText'), Array, Nothing),
    BinaryExpression(Object, Keyword('setVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('setVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('setVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('setVariable'), Array, Nothing),
    BinaryExpression(Namespace, Keyword('setVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('setVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('setVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('setVariable'), Array, Nothing),
    BinaryExpression(Object, Keyword('setVectorDir'), Array, Nothing),
    BinaryExpression(Object, Keyword('setVectorDirAndUp'), Array, Nothing),
    BinaryExpression(Object, Keyword('setVectorUp'), Array, Nothing),
    BinaryExpression(Object, Keyword('setVehicleAmmo'), Number, Nothing),
    BinaryExpression(Object, Keyword('setVehicleAmmoDef'), Number, Nothing),
    BinaryExpression(Object, Keyword('setVehicleArmor'), Number, Nothing),
    BinaryExpression(Object, Keyword('setVehicleCargo'), Object, Boolean),
    BinaryExpression(Object, Keyword('setVehicleId'), Number, Nothing),
    BinaryExpression(Object, Keyword('setVehicleLock'), String, Nothing),
    BinaryExpression(Object, Keyword('setVehiclePosition'), Array, Boolean),
    BinaryExpression(Object, Keyword('setVehicleTiPars'), Array, Nothing),
    BinaryExpression(Object, Keyword('setVehicleVarName'), String, Nothing),
    BinaryExpression(Object, Keyword('setVelocity'), Array, Nothing),
    BinaryExpression(Object, Keyword('setVelocityModelSpace'), Array, Nothing),
    BinaryExpression(Object, Keyword('setVelocityTransformation'), Array, Nothing),
    BinaryExpression(Object, Keyword('setVisibleIfTreeCollapsed'), Array, Nothing),
    BinaryExpression(Array, Keyword('setWPPos'), Array, Nothing),
    BinaryExpression(Object, Keyword('setWantedRPMRTD'), Array, Nothing),
    BinaryExpression(Number, Keyword('setWaves'), Number, Nothing),
    BinaryExpression(Array, Keyword('setWaypointBehaviour'), String, Nothing),
    BinaryExpression(Array, Keyword('setWaypointCombatMode'), String, Nothing),
    BinaryExpression(Array, Keyword('setWaypointCompletionRadius'), Number, Nothing),
    BinaryExpression(Array, Keyword('setWaypointDescription'), String, Nothing),
    BinaryExpression(Array, Keyword('setWaypointForceBehaviour'), Boolean, Nothing),
    BinaryExpression(Array, Keyword('setWaypointFormation'), String, Nothing),
    BinaryExpression(Array, Keyword('setWaypointHousePosition'), Number, Nothing),
    BinaryExpression(Array, Keyword('setWaypointLoiterRadius'), Number, Nothing),
    BinaryExpression(Array, Keyword('setWaypointLoiterType'), String, Nothing),
    BinaryExpression(Array, Keyword('setWaypointName'), String, Nothing),
    BinaryExpression(Array, Keyword('setWaypointPosition'), Array, Nothing),
    BinaryExpression(Array, Keyword('setWaypointScript'), String, Nothing),
    BinaryExpression(Array, Keyword('setWaypointSpeed'), String, Nothing),
    BinaryExpression(Array, Keyword('setWaypointStatements'), Array, Nothing),
    BinaryExpression(Array, Keyword('setWaypointTimeout'), Array, Nothing),
    BinaryExpression(Array, Keyword('setWaypointType'), String, Nothing),
    BinaryExpression(Array, Keyword('setWaypointVisible'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('setWeaponReloadingTime'), Array, Boolean),
    BinaryExpression(Number, Keyword('setWindDir'), Number, Nothing),
    BinaryExpression(Number, Keyword('setWindForce'), Number, Nothing),
    BinaryExpression(Number, Keyword('setWindStr'), Number, Nothing),
    BinaryExpression(Object, Keyword('setWingForceScaleRTD'), Array, Nothing),
    BinaryExpression(Object, Keyword('show3DIcons'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('showLegend'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('showNewEditorObject'), Array, Nothing),
    BinaryExpression(Array, Keyword('showWaypoint'), String, Nothing),
    BinaryExpression(Object, Keyword('sideChat'), String, Nothing),
    BinaryExpression(Array, Keyword('sideChat'), String, Nothing),
    BinaryExpression(Object, Keyword('sideRadio'), String, Nothing),
    BinaryExpression(Array, Keyword('sideRadio'), String, Nothing),
    BinaryExpression(Object, Keyword('skill'), String, Number),
    BinaryExpression(Object, Keyword('skillFinal'), String, Number),
    BinaryExpression(Object, Keyword('sliderSetPosition'), Number, Nothing),
    BinaryExpression(Object, Keyword('sliderSetRange'), Array, Nothing),
    BinaryExpression(Object, Keyword('sliderSetSpeed'), Array, Nothing),
    BinaryExpression(Array, Keyword('sort'), Boolean, Nothing),
    BinaryExpression(Type, Keyword('spawn'), Code, Script),
    BinaryExpression(String, Keyword('splitString'), String, Array),
    BinaryExpression(ForType, Keyword('step'), Number, ForType),
    BinaryExpression(Object, Keyword('stop'), Boolean, Nothing),
    BinaryExpression(Object, Keyword('suppressFor'), Number, Nothing),
    BinaryExpression(Object, Keyword('switchAction'), String, Nothing),
    BinaryExpression(Object, Keyword('switchCamera'), String, Nothing),
    BinaryExpression(Object, Keyword('switchGesture'), String, Nothing),
    BinaryExpression(Object, Keyword('switchLight'), String, Nothing),
    BinaryExpression(Object, Keyword('switchMove'), String, Nothing),
    BinaryExpression(Object, Keyword('synchronizeObjectsAdd'), Array, Nothing),
    BinaryExpression(Object, Keyword('synchronizeObjectsRemove'), Array, Nothing),
    BinaryExpression(Object, Keyword('synchronizeTrigger'), Array, Nothing),
    BinaryExpression(Array, Keyword('synchronizeWaypoint'), Array, Nothing),
    BinaryExpression(Object, Keyword('synchronizeWaypoint'), Array, Nothing),
    BinaryExpression(Object, Keyword('targetKnowledge'), Object, Array),
    BinaryExpression(Array, Keyword('targetsAggregate'), Array, Array),
    BinaryExpression(Object, Keyword('targetsQuery'), Array, Array),
    BinaryExpression(IfType, Keyword('then'), Code, Nothing),
    BinaryExpression(IfType, Keyword('then'), Array, Nothing),
    BinaryExpression(IfType, Keyword('throw'), Type, Nothing),
    BinaryExpression(ForType, Keyword('to'), Number, ForType),
    BinaryExpression(Number, Keyword('toFixed'), Number, String),
    BinaryExpression(Object, Keyword('triggerAttachObject'), Number, Nothing),
    BinaryExpression(Object, Keyword('triggerAttachVehicle'), Array, Nothing),
    BinaryExpression(Object, Keyword('triggerDynamicSimulation'), Boolean, Nothing),
    BinaryExpression(Type, Keyword('try'), Code, TryType),
    BinaryExpression(Object, Keyword('turretLocal'), Array, Boolean),
    BinaryExpression(Object, Keyword('turretOwner'), Array, Number),
    BinaryExpression(Object, Keyword('turretUnit'), Array, Object),
    BinaryExpression(Object, Keyword('tvAdd'), Array, Number),
    BinaryExpression(Object, Keyword('tvCollapse'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvCount'), Array, Number),
    BinaryExpression(Object, Keyword('tvData'), Array, String),
    BinaryExpression(Object, Keyword('tvDelete'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvExpand'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvPicture'), Array, String),
    BinaryExpression(Object, Keyword('tvPictureRight'), Array, String),
    BinaryExpression(Object, Keyword('tvSetColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSetCurSel'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSetData'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSetPicture'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSetPictureColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSetPictureColorDisabled'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSetPictureColorSelected'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSetPictureRight'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSetPictureRightColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSetPictureRightColorDisabled'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSetPictureRightColorSelected'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSetSelectColor'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSetText'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSetTooltip'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSetValue'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSort'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvSortByValue'), Array, Nothing),
    BinaryExpression(Object, Keyword('tvText'), Array, String),
    BinaryExpression(Object, Keyword('tvTooltip'), Array, String),
    BinaryExpression(Object, Keyword('tvValue'), Array, Number),
    BinaryExpression(Object, Keyword('unassignItem'), String, Nothing),
    BinaryExpression(Object, Keyword('unitsBelowHeight'), Number, Array),
    BinaryExpression(Array, Keyword('unitsBelowHeight'), Number, Array),
    BinaryExpression(Object, Keyword('unlinkItem'), String, Nothing),
    BinaryExpression(Object, Keyword('unregisterTask'), String, Boolean),
    BinaryExpression(Object, Keyword('updateDrawIcon'), Array, Nothing),
    BinaryExpression(Object, Keyword('updateMenuItem'), Array, Nothing),
    BinaryExpression(Object, Keyword('useAudioTimeForMoves'), Boolean, Nothing),
    BinaryExpression(Array, Keyword('vectorAdd'), Array, Array),
    BinaryExpression(Array, Keyword('vectorCos'), Array, Number),
    BinaryExpression(Array, Keyword('vectorCrossProduct'), Array, Array),
    BinaryExpression(Array, Keyword('vectorDiff'), Array, Array),
    BinaryExpression(Array, Keyword('vectorDistance'), Array, Number),
    BinaryExpression(Array, Keyword('vectorDistanceSqr'), Array, Number),
    BinaryExpression(Array, Keyword('vectorDotProduct'), Array, Number),
    BinaryExpression(Array, Keyword('vectorFromTo'), Array, Array),
    BinaryExpression(Array, Keyword('vectorMultiply'), Number, Array),
    BinaryExpression(Object, Keyword('vehicleChat'), String, Nothing),
    BinaryExpression(Object, Keyword('vehicleRadio'), String, Nothing),
    BinaryExpression(Array, Keyword('waypointAttachObject'), Object, Nothing),
    BinaryExpression(Array, Keyword('waypointAttachObject'), Number, Nothing),
    BinaryExpression(Array, Keyword('waypointAttachVehicle'), Object, Nothing),
    BinaryExpression(Object, Keyword('weaponAccessories'), String, Array),
    BinaryExpression(Object, Keyword('weaponAccessoriesCargo'), Array, Array),
    BinaryExpression(Object, Keyword('weaponDirection'), String, Array),
    BinaryExpression(Object, Keyword('weaponsTurret'), Array, Array),
    BinaryExpression(Object, Keyword('worldToModel'), Array, Array),
    BinaryExpression(Object, Keyword('worldToModelVisual'), Array, Array),
    BinaryExpression(Boolean, Keyword('||'), Boolean, Boolean),
    BinaryExpression(Boolean, Keyword('||'), Code, Boolean),
    UnaryExpression(Keyword('!'), Boolean, Boolean),
    UnaryExpression(Keyword('+'), Number, Number),
    UnaryExpression(Keyword('+'), Array, Array),
    UnaryExpression(Keyword('-'), Number, Number),
    UnaryExpression(Keyword('AGLToASL'), Array, Array),
    UnaryExpression(Keyword('AISFinishHeal'), Array, Nothing),
    UnaryExpression(Keyword('ASLToAGL'), Array, Array),
    UnaryExpression(Keyword('ASLToATL'), Array, Array),
    UnaryExpression(Keyword('ATLToASL'), Array, Array),
    UnaryExpression(Keyword('MenuClear'), Object, Nothing),
    UnaryExpression(Keyword('MenuClear'), Number, Nothing),
    UnaryExpression(Keyword('SoldierMagazines'), Object, Array),
    UnaryExpression(Keyword('UAVControl'), Object, Array),
    UnaryExpression(Keyword('WFSideText'), Object, String),
    UnaryExpression(Keyword('WFSideText'), Object, String),
    UnaryExpression(Keyword('WFSideText'), Object, String),
    UnaryExpression(Keyword('abs'), Number, Number),
    UnaryExpression(Keyword('acos'), Number, Number),
    UnaryExpression(Keyword('actionIDs'), Object, Array),
    UnaryExpression(Keyword('actionKeys'), String, Array),
    UnaryExpression(Keyword('actionKeysImages'), String, String),
    UnaryExpression(Keyword('actionKeysImages'), Array, String),
    UnaryExpression(Keyword('actionKeysNames'), String, String),
    UnaryExpression(Keyword('actionKeysNames'), Array, String),
    UnaryExpression(Keyword('actionKeysNamesArray'), String, Array),
    UnaryExpression(Keyword('actionKeysNamesArray'), Array, Array),
    UnaryExpression(Keyword('actionName'), String, String),
    UnaryExpression(Keyword('activateAddons'), Array, Nothing),
    UnaryExpression(Keyword('activateKey'), String, Nothing),
    UnaryExpression(Keyword('add3DENConnection'), Array, Nothing),
    UnaryExpression(Keyword('add3DENEventHandler'), Array, Number),
    UnaryExpression(Keyword('addCamShake'), Array, Nothing),
    UnaryExpression(Keyword('addForceGeneratorRTD'), Array, Number),
    UnaryExpression(Keyword('addItemPool'), Array, Nothing),
    UnaryExpression(Keyword('addMagazinePool'), Array, Nothing),
    UnaryExpression(Keyword('addMissionEventHandler'), Array, Number),
    UnaryExpression(Keyword('addMusicEventHandler'), Array, Number),
    UnaryExpression(Keyword('addSwitchableUnit'), Object, Nothing),
    UnaryExpression(Keyword('addToRemainsCollector'), Array, Nothing),
    UnaryExpression(Keyword('addWeaponPool'), Array, Nothing),
    UnaryExpression(Keyword('agent'), Object, Object),
    UnaryExpression(Keyword('aimPos'), Object, Array),
    UnaryExpression(Keyword('airDensityRTD'), Number, Number),
    UnaryExpression(Keyword('airportSide'), Object, Nothing),
    UnaryExpression(Keyword('airportSide'), Number, Nothing),
    UnaryExpression(Keyword('alive'), Object, Boolean),
    UnaryExpression(Keyword('allControls'), Object, Array),
    UnaryExpression(Keyword('allMissionObjects'), String, Array),
    UnaryExpression(Keyword('allSimpleObjects'), Array, Array),
    UnaryExpression(Keyword('allTurrets'), Array, Array),
    UnaryExpression(Keyword('allTurrets'), Object, Array),
    UnaryExpression(Keyword('allVariables'), Object, Array),
    UnaryExpression(Keyword('allVariables'), Object, Array),
    UnaryExpression(Keyword('allVariables'), Namespace, Array),
    UnaryExpression(Keyword('allVariables'), Object, Array),
    UnaryExpression(Keyword('allVariables'), Object, Array),
    UnaryExpression(Keyword('allVariables'), Object, Array),
    UnaryExpression(Keyword('allVariables'), Object, Array),
    UnaryExpression(Keyword('animationNames'), Object, Array),
    UnaryExpression(Keyword('animationState'), Object, String),
    UnaryExpression(Keyword('asin'), Number, Number),
    UnaryExpression(Keyword('assert'), Boolean, Boolean),
    UnaryExpression(Keyword('assignedCargo'), Object, Array),
    UnaryExpression(Keyword('assignedCommander'), Object, Object),
    UnaryExpression(Keyword('assignedDriver'), Object, Object),
    UnaryExpression(Keyword('assignedGunner'), Object, Object),
    UnaryExpression(Keyword('assignedItems'), Object, Array),
    UnaryExpression(Keyword('assignedTarget'), Object, Object),
    UnaryExpression(Keyword('assignedTeam'), Object, String),
    UnaryExpression(Keyword('assignedVehicle'), Object, Object),
    UnaryExpression(Keyword('assignedVehicleRole'), Object, Array),
    UnaryExpression(Keyword('atan'), Number, Number),
    UnaryExpression(Keyword('atg'), Number, Number),
    UnaryExpression(Keyword('attachedObject'), Object, Object),
    UnaryExpression(Keyword('attachedObjects'), Object, Array),
    UnaryExpression(Keyword('attachedTo'), Object, Object),
    UnaryExpression(Keyword('attackEnabled'), Object, Boolean),
    UnaryExpression(Keyword('attackEnabled'), Object, Boolean),
    UnaryExpression(Keyword('backpack'), Object, String),
    UnaryExpression(Keyword('backpackCargo'), Object, Array),
    UnaryExpression(Keyword('backpackContainer'), Object, Object),
    UnaryExpression(Keyword('backpackItems'), Object, Array),
    UnaryExpression(Keyword('backpackMagazines'), Object, Array),
    UnaryExpression(Keyword('behaviour'), Object, String),
    UnaryExpression(Keyword('binocular'), Object, String),
    UnaryExpression(Keyword('boundingBox'), Object, Array),
    UnaryExpression(Keyword('boundingBoxReal'), Object, Array),
    UnaryExpression(Keyword('boundingCenter'), Object, Array),
    UnaryExpression(Keyword('breakOut'), String, Nothing),
    UnaryExpression(Keyword('breakTo'), String, Nothing),
    UnaryExpression(Keyword('buldozer_EnableRoadDiag'), Boolean, Nothing),
    UnaryExpression(Keyword('buldozer_LoadNewRoads'), String, Boolean),
    UnaryExpression(Keyword('buttonAction'), Object, String),
    UnaryExpression(Keyword('buttonAction'), Number, String),
    UnaryExpression(Keyword('buttonSetAction'), Array, Nothing),
    UnaryExpression(Keyword('call'), Code, Nothing),
    UnaryExpression(Keyword('camCommitted'), Object, Boolean),
    UnaryExpression(Keyword('camDestroy'), Object, Nothing),
    UnaryExpression(Keyword('camPreloaded'), Object, Boolean),
    UnaryExpression(Keyword('camTarget'), Object, Object),
    UnaryExpression(Keyword('camUseNVG'), Boolean, Nothing),
    UnaryExpression(Keyword('cameraEffectEnableHUD'), Boolean, Nothing),
    UnaryExpression(Keyword('cameraInterest'), Object, Number),
    UnaryExpression(Keyword('canFire'), Object, Boolean),
    UnaryExpression(Keyword('canMove'), Object, Boolean),
    UnaryExpression(Keyword('canStand'), Object, Boolean),
    UnaryExpression(Keyword('canTriggerDynamicSimulation'), Object, Boolean),
    UnaryExpression(Keyword('canUnloadInCombat'), Object, Boolean),
    UnaryExpression(Keyword('cancelSimpleTaskDestination'), Object, Nothing),
    UnaryExpression(Keyword('captive'), Object, Boolean),
    UnaryExpression(Keyword('captiveNum'), Object, Number),
    UnaryExpression(Keyword('case'), Type, SwitchType),
    UnaryExpression(Keyword('cbChecked'), Object, Boolean),
    UnaryExpression(Keyword('ceil'), Number, Number),
    UnaryExpression(Keyword('channelEnabled'), Number, Array),
    UnaryExpression(Keyword('checkAIFeature'), String, Boolean),
    UnaryExpression(Keyword('className'), Object, String),
    UnaryExpression(Keyword('clear3DENInventory'), Array, Nothing),
    UnaryExpression(Keyword('clearAllItemsFromBackpack'), Object, Nothing),
    UnaryExpression(Keyword('clearBackpackCargo'), Object, Nothing),
    UnaryExpression(Keyword('clearBackpackCargoGlobal'), Object, Nothing),
    UnaryExpression(Keyword('clearGroupIcons'), Object, Nothing),
    UnaryExpression(Keyword('clearItemCargo'), Object, Nothing),
    UnaryExpression(Keyword('clearItemCargoGlobal'), Object, Nothing),
    UnaryExpression(Keyword('clearMagazineCargo'), Object, Nothing),
    UnaryExpression(Keyword('clearMagazineCargoGlobal'), Object, Nothing),
    UnaryExpression(Keyword('clearOverlay'), Object, Nothing),
    UnaryExpression(Keyword('clearWeaponCargo'), Object, Nothing),
    UnaryExpression(Keyword('clearWeaponCargoGlobal'), Object, Nothing),
    UnaryExpression(Keyword('closeDialog'), Number, Nothing),
    UnaryExpression(Keyword('closeOverlay'), Object, Nothing),
    UnaryExpression(Keyword('collapseObjectTree'), Object, Nothing),
    UnaryExpression(Keyword('collect3DENHistory'), Code, Nothing),
    UnaryExpression(Keyword('collectiveRTD'), Object, Number),
    UnaryExpression(Keyword('combatMode'), Object, String),
    UnaryExpression(Keyword('combatMode'), Object, String),
    UnaryExpression(Keyword('commandGetOut'), Object, Nothing),
    UnaryExpression(Keyword('commandGetOut'), Array, Nothing),
    UnaryExpression(Keyword('commandStop'), Object, Nothing),
    UnaryExpression(Keyword('commandStop'), Array, Nothing),
    UnaryExpression(Keyword('commander'), Object, Object),
    UnaryExpression(Keyword('comment'), String, Nothing),
    UnaryExpression(Keyword('commitOverlay'), Object, Nothing),
    UnaryExpression(Keyword('compile'), String, Code),
    UnaryExpression(Keyword('compileFinal'), String, Code),
    UnaryExpression(Keyword('completedFSM'), Number, Boolean),
    UnaryExpression(Keyword('composeText'), Array, String),
    UnaryExpression(Keyword('configHierarchy'), Config, Array),
    UnaryExpression(Keyword('configName'), Config, String),
    UnaryExpression(Keyword('configProperties'), Array, Array),
    UnaryExpression(Keyword('configSourceAddonList'), Config, Array),
    UnaryExpression(Keyword('configSourceMod'), Config, String),
    UnaryExpression(Keyword('configSourceModList'), Config, Array),
    UnaryExpression(Keyword('copyToClipboard'), String, Nothing),
    UnaryExpression(Keyword('cos'), Number, Number),
    UnaryExpression(Keyword('count'), Array, Number),
    UnaryExpression(Keyword('count'), String, Number),
    UnaryExpression(Keyword('count'), Config, Number),
    UnaryExpression(Keyword('create3DENComposition'), Array, Array),
    UnaryExpression(Keyword('create3DENEntity'), Array, Nothing),
    UnaryExpression(Keyword('createAgent'), Array, Object),
    UnaryExpression(Keyword('createCenter'), Object, Object),
    UnaryExpression(Keyword('createDialog'), String, Boolean),
    UnaryExpression(Keyword('createDiaryLink'), Array, String),
    UnaryExpression(Keyword('createGearDialog'), Array, Nothing),
    UnaryExpression(Keyword('createGroup'), Object, Object),
    UnaryExpression(Keyword('createGroup'), Array, Object),
    UnaryExpression(Keyword('createGuardedPoint'), Array, Nothing),
    UnaryExpression(Keyword('createLocation'), Array, Object),
    UnaryExpression(Keyword('createMarker'), Array, String),
    UnaryExpression(Keyword('createMarkerLocal'), Array, String),
    UnaryExpression(Keyword('createMine'), Array, Object),
    UnaryExpression(Keyword('createSimpleObject'), Array, Object),
    UnaryExpression(Keyword('createSoundSource'), Array, Object),
    UnaryExpression(Keyword('createTeam'), Array, Object),
    UnaryExpression(Keyword('createTrigger'), Array, Object),
    UnaryExpression(Keyword('createVehicle'), Array, Object),
    UnaryExpression(Keyword('createVehicleCrew'), Object, Nothing),
    UnaryExpression(Keyword('crew'), Object, Array),
    UnaryExpression(Keyword('ctrlActivate'), Object, Nothing),
    UnaryExpression(Keyword('ctrlAngle'), Object, Array),
    UnaryExpression(Keyword('ctrlAutoScrollDelay'), Object, Number),
    UnaryExpression(Keyword('ctrlAutoScrollRewind'), Object, Boolean),
    UnaryExpression(Keyword('ctrlAutoScrollSpeed'), Object, Number),
    UnaryExpression(Keyword('ctrlChecked'), Object, Boolean),
    UnaryExpression(Keyword('ctrlClassName'), Object, String),
    UnaryExpression(Keyword('ctrlCommitted'), Object, Boolean),
    UnaryExpression(Keyword('ctrlDelete'), Object, Boolean),
    UnaryExpression(Keyword('ctrlEnable'), Array, Nothing),
    UnaryExpression(Keyword('ctrlEnabled'), Object, Boolean),
    UnaryExpression(Keyword('ctrlEnabled'), Number, Boolean),
    UnaryExpression(Keyword('ctrlFade'), Object, Number),
    UnaryExpression(Keyword('ctrlHTMLLoaded'), Object, Boolean),
    UnaryExpression(Keyword('ctrlIDC'), Object, Number),
    UnaryExpression(Keyword('ctrlIDD'), Object, Number),
    UnaryExpression(Keyword('ctrlMapAnimClear'), Object, Nothing),
    UnaryExpression(Keyword('ctrlMapAnimCommit'), Object, Nothing),
    UnaryExpression(Keyword('ctrlMapAnimDone'), Object, Boolean),
    UnaryExpression(Keyword('ctrlMapMouseOver'), Object, Array),
    UnaryExpression(Keyword('ctrlMapScale'), Object, Number),
    UnaryExpression(Keyword('ctrlModel'), Object, String),
    UnaryExpression(Keyword('ctrlModelDirAndUp'), Object, Array),
    UnaryExpression(Keyword('ctrlModelScale'), Object, Number),
    UnaryExpression(Keyword('ctrlParent'), Object, Object),
    UnaryExpression(Keyword('ctrlParentControlsGroup'), Object, Object),
    UnaryExpression(Keyword('ctrlPosition'), Object, Array),
    UnaryExpression(Keyword('ctrlScale'), Object, Number),
    UnaryExpression(Keyword('ctrlSetFocus'), Object, Nothing),
    UnaryExpression(Keyword('ctrlSetText'), Array, Nothing),
    UnaryExpression(Keyword('ctrlShow'), Array, Nothing),
    UnaryExpression(Keyword('ctrlShown'), Object, Boolean),
    UnaryExpression(Keyword('ctrlText'), Object, String),
    UnaryExpression(Keyword('ctrlText'), Number, String),
    UnaryExpression(Keyword('ctrlTextHeight'), Object, Number),
    UnaryExpression(Keyword('ctrlTextSecondary'), Object, String),
    UnaryExpression(Keyword('ctrlType'), Object, Number),
    UnaryExpression(Keyword('ctrlVisible'), Number, Boolean),
    UnaryExpression(Keyword('curatorAddons'), Object, Array),
    UnaryExpression(Keyword('curatorCameraArea'), Object, Array),
    UnaryExpression(Keyword('curatorCameraAreaCeiling'), Object, Number),
    UnaryExpression(Keyword('curatorEditableObjects'), Object, Array),
    UnaryExpression(Keyword('curatorEditingArea'), Object, Array),
    UnaryExpression(Keyword('curatorEditingAreaType'), Object, Boolean),
    UnaryExpression(Keyword('curatorPoints'), Object, Number),
    UnaryExpression(Keyword('curatorRegisteredObjects'), Object, Array),
    UnaryExpression(Keyword('curatorWaypointCost'), Object, Number),
    UnaryExpression(Keyword('currentCommand'), Object, String),
    UnaryExpression(Keyword('currentMagazine'), Object, String),
    UnaryExpression(Keyword('currentMagazineDetail'), Object, Array),
    UnaryExpression(Keyword('currentMuzzle'), Object, String),
    UnaryExpression(Keyword('currentTask'), Object, Object),
    UnaryExpression(Keyword('currentTasks'), Object, Array),
    UnaryExpression(Keyword('currentThrowable'), Object, Array),
    UnaryExpression(Keyword('currentVisionMode'), Object, Number),
    UnaryExpression(Keyword('currentWaypoint'), Object, Number),
    UnaryExpression(Keyword('currentWeapon'), Object, String),
    UnaryExpression(Keyword('currentWeaponMode'), Object, String),
    UnaryExpression(Keyword('currentZeroing'), Object, Number),
    UnaryExpression(Keyword('cutObj'), Array, Nothing),
    UnaryExpression(Keyword('cutRsc'), Array, Nothing),
    UnaryExpression(Keyword('cutText'), Array, Nothing),
    UnaryExpression(Keyword('damage'), Object, Number),
    UnaryExpression(Keyword('dateToNumber'), Array, Number),
    UnaryExpression(Keyword('deActivateKey'), String, Nothing),
    UnaryExpression(Keyword('debriefingText'), String, Number),
    UnaryExpression(Keyword('debugLog'), Type, Nothing),
    UnaryExpression(Keyword('default'), Code, Nothing),
    UnaryExpression(Keyword('deg'), Number, Number),
    UnaryExpression(Keyword('delete3DENEntities'), Array, Nothing),
    UnaryExpression(Keyword('deleteCenter'), Object, Nothing),
    UnaryExpression(Keyword('deleteCollection'), Object, Nothing),
    UnaryExpression(Keyword('deleteGroup'), Object, Nothing),
    UnaryExpression(Keyword('deleteIdentity'), String, Boolean),
    UnaryExpression(Keyword('deleteLocation'), Object, Nothing),
    UnaryExpression(Keyword('deleteMarker'), String, Nothing),
    UnaryExpression(Keyword('deleteMarkerLocal'), String, Nothing),
    UnaryExpression(Keyword('deleteSite'), Object, Nothing),
    UnaryExpression(Keyword('deleteStatus'), String, Boolean),
    UnaryExpression(Keyword('deleteTeam'), Object, Nothing),
    UnaryExpression(Keyword('deleteVehicle'), Object, Nothing),
    UnaryExpression(Keyword('deleteWaypoint'), Array, Nothing),
    UnaryExpression(Keyword('detach'), Object, Nothing),
    UnaryExpression(Keyword('detectedMines'), Object, Array),
    UnaryExpression(Keyword('diag_captureFrame'), Number, Nothing),
    UnaryExpression(Keyword('diag_captureFrameToFile'), Number, Nothing),
    UnaryExpression(Keyword('diag_captureSlowFrame'), Array, Nothing),
    UnaryExpression(Keyword('diag_codePerformance'), Array, Array),
    UnaryExpression(Keyword('diag_dynamicSimulationEnd'), String, Nothing),
    UnaryExpression(Keyword('diag_log'), Type, Nothing),
    UnaryExpression(Keyword('diag_logSlowFrame'), Array, Nothing),
    UnaryExpression(Keyword('didJIPOwner'), Object, Boolean),
    UnaryExpression(Keyword('difficultyEnabled'), String, Boolean),
    UnaryExpression(Keyword('difficultyOption'), String, Number),
    UnaryExpression(Keyword('direction'), Object, Number),
    UnaryExpression(Keyword('direction'), Object, Number),
    UnaryExpression(Keyword('disableRemoteSensors'), Boolean, Nothing),
    UnaryExpression(Keyword('disableUserInput'), Boolean, Nothing),
    UnaryExpression(Keyword('displayParent'), Object, Object),
    UnaryExpression(Keyword('dissolveTeam'), String, Nothing),
    UnaryExpression(Keyword('do3DENAction'), String, Nothing),
    UnaryExpression(Keyword('doGetOut'), Object, Nothing),
    UnaryExpression(Keyword('doGetOut'), Array, Nothing),
    UnaryExpression(Keyword('doStop'), Object, Nothing),
    UnaryExpression(Keyword('doStop'), Array, Nothing),
    UnaryExpression(Keyword('drawIcon3D'), Array, Nothing),
    UnaryExpression(Keyword('drawLine3D'), Array, Nothing),
    UnaryExpression(Keyword('driver'), Object, Object),
    UnaryExpression(Keyword('drop'), Array, Nothing),
    UnaryExpression(Keyword('dynamicSimulationDistance'), String, Number),
    UnaryExpression(Keyword('dynamicSimulationDistanceCoef'), String, Number),
    UnaryExpression(Keyword('dynamicSimulationEnabled'), Object, Boolean),
    UnaryExpression(Keyword('dynamicSimulationEnabled'), Object, Boolean),
    UnaryExpression(Keyword('echo'), String, Nothing),
    UnaryExpression(Keyword('edit3DENMissionAttributes'), String, Nothing),
    UnaryExpression(Keyword('effectiveCommander'), Object, Object),
    UnaryExpression(Keyword('enableAudioFeature'), Array, Boolean),
    UnaryExpression(Keyword('enableCamShake'), Boolean, Nothing),
    UnaryExpression(Keyword('enableCaustics'), Boolean, Nothing),
    UnaryExpression(Keyword('enableDebriefingStats'), Array, Nothing),
    UnaryExpression(Keyword('enableDiagLegend'), Boolean, Nothing),
    UnaryExpression(Keyword('enableDynamicSimulationSystem'), Boolean, Nothing),
    UnaryExpression(Keyword('enableEngineArtillery'), Boolean, Nothing),
    UnaryExpression(Keyword('enableEnvironment'), Boolean, Nothing),
    UnaryExpression(Keyword('enableEnvironment'), Array, Nothing),
    UnaryExpression(Keyword('enableRadio'), Boolean, Nothing),
    UnaryExpression(Keyword('enableSatNormalOnDetail'), Boolean, Nothing),
    UnaryExpression(Keyword('enableSaving'), Boolean, Nothing),
    UnaryExpression(Keyword('enableSaving'), Array, Nothing),
    UnaryExpression(Keyword('enableSentences'), Boolean, Nothing),
    UnaryExpression(Keyword('enableStressDamage'), Boolean, Nothing),
    UnaryExpression(Keyword('enableTeamSwitch'), Boolean, Nothing),
    UnaryExpression(Keyword('enableTraffic'), Boolean, Nothing),
    UnaryExpression(Keyword('enableWeaponDisassembly'), Boolean, Nothing),
    UnaryExpression(Keyword('endMission'), String, Nothing),
    UnaryExpression(Keyword('enginesIsOnRTD'), Object, Array),
    UnaryExpression(Keyword('enginesPowerRTD'), Object, Array),
    UnaryExpression(Keyword('enginesRpmRTD'), Object, Array),
    UnaryExpression(Keyword('enginesTorqueRTD'), Object, Array),
    UnaryExpression(Keyword('entities'), String, Array),
    UnaryExpression(Keyword('entities'), Array, Array),
    UnaryExpression(Keyword('estimatedTimeLeft'), Number, Nothing),
    UnaryExpression(Keyword('everyBackpack'), Object, Array),
    UnaryExpression(Keyword('everyContainer'), Object, Array),
    UnaryExpression(Keyword('execFSM'), String, Number),
    UnaryExpression(Keyword('execVM'), String, Script),
    UnaryExpression(Keyword('exp'), Number, Number),
    UnaryExpression(Keyword('expectedDestination'), Object, Array),
    UnaryExpression(Keyword('exportJIPMessages'), String, Nothing),
    UnaryExpression(Keyword('eyeDirection'), Object, Array),
    UnaryExpression(Keyword('eyePos'), Object, Array),
    UnaryExpression(Keyword('face'), Object, String),
    UnaryExpression(Keyword('faction'), Object, String),
    UnaryExpression(Keyword('failMission'), String, Nothing),
    UnaryExpression(Keyword('fillWeaponsFromPool'), Object, Nothing),
    UnaryExpression(Keyword('findDisplay'), Number, Object),
    UnaryExpression(Keyword('finite'), Number, Boolean),
    UnaryExpression(Keyword('firstBackpack'), Object, Object),
    UnaryExpression(Keyword('flag'), Object, Object),
    UnaryExpression(Keyword('flagAnimationPhase'), Object, Number),
    UnaryExpression(Keyword('flagOwner'), Object, Object),
    UnaryExpression(Keyword('flagSide'), Object, Object),
    UnaryExpression(Keyword('flagTexture'), Object, String),
    UnaryExpression(Keyword('fleeing'), Object, Boolean),
    UnaryExpression(Keyword('floor'), Number, Number),
    UnaryExpression(Keyword('for'), String, ForType),
    UnaryExpression(Keyword('for'), Array, ForType),
    UnaryExpression(Keyword('forceAtPositionRTD'), Array, Array),
    UnaryExpression(Keyword('forceGeneratorRTD'), Number, Array),
    UnaryExpression(Keyword('forceMap'), Boolean, Nothing),
    UnaryExpression(Keyword('forceRespawn'), Object, Nothing),
    UnaryExpression(Keyword('formLeader'), Object, Object),
    UnaryExpression(Keyword('format'), Array, String),
    UnaryExpression(Keyword('formatText'), Array, String),
    UnaryExpression(Keyword('formation'), Object, String),
    UnaryExpression(Keyword('formation'), Object, String),
    UnaryExpression(Keyword('formation'), Object, String),
    UnaryExpression(Keyword('formationDirection'), Object, Number),
    UnaryExpression(Keyword('formationLeader'), Object, Object),
    UnaryExpression(Keyword('formationMembers'), Object, Array),
    UnaryExpression(Keyword('formationPosition'), Object, Array),
    UnaryExpression(Keyword('formationTask'), Object, String),
    UnaryExpression(Keyword('fromEditor'), Object, Boolean),
    UnaryExpression(Keyword('fuel'), Object, Number),
    UnaryExpression(Keyword('fullCrew'), Object, Array),
    UnaryExpression(Keyword('fullCrew'), Array, Array),
    UnaryExpression(Keyword('gearIDCAmmoCount'), Number, Number),
    UnaryExpression(Keyword('gearSlotAmmoCount'), Object, Number),
    UnaryExpression(Keyword('gearSlotData'), Object, String),
    UnaryExpression(Keyword('get3DENActionState'), String, Number),
    UnaryExpression(Keyword('get3DENConnections'), Type, Array),
    UnaryExpression(Keyword('get3DENEntity'), Number, Nothing),
    UnaryExpression(Keyword('get3DENEntityID'), Type, Number),
    UnaryExpression(Keyword('get3DENGrid'), String, Nothing),
    UnaryExpression(Keyword('get3DENLayerEntities'), Number, Array),
    UnaryExpression(Keyword('get3DENSelected'), String, Array),
    UnaryExpression(Keyword('getAimingCoef'), Object, Number),
    UnaryExpression(Keyword('getAllEnvSoundControllers'), Array, Array),
    UnaryExpression(Keyword('getAllHitPointsDamage'), Object, Array),
    UnaryExpression(Keyword('getAllOwnedMines'), Object, Array),
    UnaryExpression(Keyword('getAllSoundControllers'), Object, Array),
    UnaryExpression(Keyword('getAmmoCargo'), Object, Number),
    UnaryExpression(Keyword('getAnimAimPrecision'), Object, Number),
    UnaryExpression(Keyword('getAnimSpeedCoef'), Object, Number),
    UnaryExpression(Keyword('getArray'), Config, Array),
    UnaryExpression(Keyword('getArtilleryAmmo'), Array, Array),
    UnaryExpression(Keyword('getAssignedCuratorLogic'), Object, Object),
    UnaryExpression(Keyword('getAssignedCuratorUnit'), Object, Object),
    UnaryExpression(Keyword('getBackpackCargo'), Object, Array),
    UnaryExpression(Keyword('getBleedingRemaining'), Object, Number),
    UnaryExpression(Keyword('getBurningValue'), Object, Number),
    UnaryExpression(Keyword('getCameraViewDirection'), Object, Array),
    UnaryExpression(Keyword('getCenterOfMass'), Object, Array),
    UnaryExpression(Keyword('getConnectedUAV'), Object, Object),
    UnaryExpression(Keyword('getContainerMaxLoad'), String, Number),
    UnaryExpression(Keyword('getCustomAimCoef'), Object, Number),
    UnaryExpression(Keyword('getDLCAssetsUsageByName'), String, Array),
    UnaryExpression(Keyword('getDLCUsageTime'), Number, Number),
    UnaryExpression(Keyword('getDLCs'), Number, Array),
    UnaryExpression(Keyword('getDammage'), Object, Number),
    UnaryExpression(Keyword('getDescription'), Object, Array),
    UnaryExpression(Keyword('getDir'), Object, Number),
    UnaryExpression(Keyword('getDirVisual'), Object, Number),
    UnaryExpression(Keyword('getEditorCamera'), Object, Object),
    UnaryExpression(Keyword('getEditorMode'), Object, String),
    UnaryExpression(Keyword('getEngineTargetRPMRTD'), Object, Array),
    UnaryExpression(Keyword('getFatigue'), Object, Number),
    UnaryExpression(Keyword('getFieldManualStartPage'), Object, Array),
    UnaryExpression(Keyword('getFuelCargo'), Object, Number),
    UnaryExpression(Keyword('getGroupIconParams'), Object, Array),
    UnaryExpression(Keyword('getGroupIcons'), Object, Array),
    UnaryExpression(Keyword('getItemCargo'), Object, Array),
    UnaryExpression(Keyword('getMagazineCargo'), Object, Array),
    UnaryExpression(Keyword('getMarkerColor'), String, String),
    UnaryExpression(Keyword('getMarkerPos'), String, Array),
    UnaryExpression(Keyword('getMarkerSize'), String, Array),
    UnaryExpression(Keyword('getMarkerType'), String, String),
    UnaryExpression(Keyword('getMass'), Object, Number),
    UnaryExpression(Keyword('getMissionConfig'), String, Config),
    UnaryExpression(Keyword('getMissionConfigValue'), String, Nothing),
    UnaryExpression(Keyword('getMissionConfigValue'), Array, Nothing),
    UnaryExpression(Keyword('getMissionLayerEntities'), String, Array),
    UnaryExpression(Keyword('getMissionLayerEntities'), Number, Array),
    UnaryExpression(Keyword('getModelInfo'), Object, Array),
    UnaryExpression(Keyword('getNumber'), Config, Number),
    UnaryExpression(Keyword('getObjectDLC'), Object, Number),
    UnaryExpression(Keyword('getObjectMaterials'), Object, Array),
    UnaryExpression(Keyword('getObjectTextures'), Object, Array),
    UnaryExpression(Keyword('getObjectType'), Object, Number),
    UnaryExpression(Keyword('getOxygenRemaining'), Object, Number),
    UnaryExpression(Keyword('getPersonUsedDLCs'), Object, Array),
    UnaryExpression(Keyword('getPilotCameraDirection'), Object, Array),
    UnaryExpression(Keyword('getPilotCameraPosition'), Object, Array),
    UnaryExpression(Keyword('getPilotCameraRotation'), Object, Array),
    UnaryExpression(Keyword('getPilotCameraTarget'), Object, Array),
    UnaryExpression(Keyword('getPlayerChannel'), Object, Number),
    UnaryExpression(Keyword('getPlayerScores'), Object, Array),
    UnaryExpression(Keyword('getPlayerUID'), Object, String),
    UnaryExpression(Keyword('getPos'), Object, Array),
    UnaryExpression(Keyword('getPos'), Object, Array),
    UnaryExpression(Keyword('getPosASL'), Object, Array),
    UnaryExpression(Keyword('getPosASLVisual'), Object, Array),
    UnaryExpression(Keyword('getPosASLW'), Object, Array),
    UnaryExpression(Keyword('getPosATL'), Object, Array),
    UnaryExpression(Keyword('getPosATLVisual'), Object, Array),
    UnaryExpression(Keyword('getPosVisual'), Object, Array),
    UnaryExpression(Keyword('getPosWorld'), Object, Array),
    UnaryExpression(Keyword('getRepairCargo'), Object, Number),
    UnaryExpression(Keyword('getRotorBrakeRTD'), Object, Number),
    UnaryExpression(Keyword('getShotParents'), Object, Array),
    UnaryExpression(Keyword('getSlingLoad'), Object, Object),
    UnaryExpression(Keyword('getStamina'), Object, Number),
    UnaryExpression(Keyword('getStatValue'), String, Number),
    UnaryExpression(Keyword('getSuppression'), Object, Number),
    UnaryExpression(Keyword('getTerrainHeightASL'), Array, Number),
    UnaryExpression(Keyword('getText'), Config, String),
    UnaryExpression(Keyword('getTrimOffsetRTD'), Object, Array),
    UnaryExpression(Keyword('getUnitLoadout'), Object, Array),
    UnaryExpression(Keyword('getUnitLoadout'), Array, Array),
    UnaryExpression(Keyword('getUnitLoadout'), String, Array),
    UnaryExpression(Keyword('getUnitLoadout'), Config, Array),
    UnaryExpression(Keyword('getVehicleCargo'), Object, Array),
    UnaryExpression(Keyword('getWPPos'), Array, Array),
    UnaryExpression(Keyword('getWeaponCargo'), Object, Array),
    UnaryExpression(Keyword('getWeaponSway'), Object, Number),
    UnaryExpression(Keyword('getWingsOrientationRTD'), Object, Number),
    UnaryExpression(Keyword('getWingsPositionRTD'), Object, Number),
    UnaryExpression(Keyword('goggles'), Object, String),
    UnaryExpression(Keyword('goto'), String, Nothing),
    UnaryExpression(Keyword('group'), Object, Object),
    UnaryExpression(Keyword('groupFromNetId'), String, Object),
    UnaryExpression(Keyword('groupID'), Object, String),
    UnaryExpression(Keyword('groupOwner'), Object, Number),
    UnaryExpression(Keyword('groupSelectedUnits'), Object, Array),
    UnaryExpression(Keyword('gunner'), Object, Object),
    UnaryExpression(Keyword('handgunItems'), Object, Array),
    UnaryExpression(Keyword('handgunMagazine'), Object, Array),
    UnaryExpression(Keyword('handgunWeapon'), Object, String),
    UnaryExpression(Keyword('handsHit'), Object, Number),
    UnaryExpression(Keyword('hasPilotCamera'), Object, Boolean),
    UnaryExpression(Keyword('hcAllGroups'), Object, Array),
    UnaryExpression(Keyword('hcLeader'), Object, Object),
    UnaryExpression(Keyword('hcRemoveAllGroups'), Object, Nothing),
    UnaryExpression(Keyword('hcSelected'), Object, Array),
    UnaryExpression(Keyword('hcShowBar'), Boolean, Nothing),
    UnaryExpression(Keyword('headgear'), Object, String),
    UnaryExpression(Keyword('hideBody'), Object, Nothing),
    UnaryExpression(Keyword('hideObject'), Object, Nothing),
    UnaryExpression(Keyword('hideObjectGlobal'), Object, Nothing),
    UnaryExpression(Keyword('hint'), String, Nothing),
    UnaryExpression(Keyword('hint'), String, Nothing),
    UnaryExpression(Keyword('hintC'), String, Nothing),
    UnaryExpression(Keyword('hintCadet'), String, Nothing),
    UnaryExpression(Keyword('hintCadet'), String, Nothing),
    UnaryExpression(Keyword('hintSilent'), String, Nothing),
    UnaryExpression(Keyword('hintSilent'), String, Nothing),
    UnaryExpression(Keyword('hmd'), Object, String),
    UnaryExpression(Keyword('hostMission'), Array, Nothing),
    UnaryExpression(Keyword('if'), Boolean, IfType),
    UnaryExpression(Keyword('image'), String, String),
    UnaryExpression(Keyword('importAllGroups'), Object, Nothing),
    UnaryExpression(Keyword('importance'), Object, Number),
    UnaryExpression(Keyword('inGameUISetEventHandler'), Array, Nothing),
    UnaryExpression(Keyword('incapacitatedState'), Object, String),
    UnaryExpression(Keyword('inflamed'), Object, Boolean),
    UnaryExpression(Keyword('inheritsFrom'), Config, Config),
    UnaryExpression(Keyword('inputAction'), String, Number),
    UnaryExpression(Keyword('isAbleToBreathe'), Object, Boolean),
    UnaryExpression(Keyword('isAgent'), Object, Boolean),
    UnaryExpression(Keyword('isAimPrecisionEnabled'), Object, Boolean),
    UnaryExpression(Keyword('isArray'), Config, Boolean),
    UnaryExpression(Keyword('isAutoHoverOn'), Object, Boolean),
    UnaryExpression(Keyword('isAutoStartUpEnabledRTD'), Object, Array),
    UnaryExpression(Keyword('isAutoTrimOnRTD'), Object, Boolean),
    UnaryExpression(Keyword('isAutonomous'), Object, Boolean),
    UnaryExpression(Keyword('isBleeding'), Object, Boolean),
    UnaryExpression(Keyword('isBurning'), Object, Boolean),
    UnaryExpression(Keyword('isClass'), Config, Boolean),
    UnaryExpression(Keyword('isCollisionLightOn'), Object, Boolean),
    UnaryExpression(Keyword('isCopilotEnabled'), Object, Boolean),
    UnaryExpression(Keyword('isDLCAvailable'), Number, Boolean),
    UnaryExpression(Keyword('isEngineOn'), Object, Boolean),
    UnaryExpression(Keyword('isForcedWalk'), Object, Boolean),
    UnaryExpression(Keyword('isFormationLeader'), Object, Boolean),
    UnaryExpression(Keyword('isGroupDeletedWhenEmpty'), Object, Boolean),
    UnaryExpression(Keyword('isHidden'), Object, Boolean),
    UnaryExpression(Keyword('isInRemainsCollector'), Object, Boolean),
    UnaryExpression(Keyword('isKeyActive'), String, Boolean),
    UnaryExpression(Keyword('isLightOn'), Object, Boolean),
    UnaryExpression(Keyword('isLocalized'), String, Boolean),
    UnaryExpression(Keyword('isManualFire'), Object, Boolean),
    UnaryExpression(Keyword('isMarkedForCollection'), Object, Boolean),
    UnaryExpression(Keyword('isNil'), Code, Boolean),
    UnaryExpression(Keyword('isNil'), String, Boolean),
    UnaryExpression(Keyword('isNull'), Object, Boolean),
    UnaryExpression(Keyword('isNull'), Object, Boolean),
    UnaryExpression(Keyword('isNull'), Script, Boolean),
    UnaryExpression(Keyword('isNull'), Config, Boolean),
    UnaryExpression(Keyword('isNull'), Object, Boolean),
    UnaryExpression(Keyword('isNull'), Object, Boolean),
    UnaryExpression(Keyword('isNull'), Object, Boolean),
    UnaryExpression(Keyword('isNull'), Object, Boolean),
    UnaryExpression(Keyword('isNull'), Object, Boolean),
    UnaryExpression(Keyword('isNumber'), Config, Boolean),
    UnaryExpression(Keyword('isObjectHidden'), Object, Boolean),
    UnaryExpression(Keyword('isObjectRTD'), Object, Boolean),
    UnaryExpression(Keyword('isOnRoad'), Object, Boolean),
    UnaryExpression(Keyword('isOnRoad'), Array, Boolean),
    UnaryExpression(Keyword('isPlayer'), Object, Boolean),
    UnaryExpression(Keyword('isRealTime'), Object, Boolean),
    UnaryExpression(Keyword('isShowing3DIcons'), Object, Boolean),
    UnaryExpression(Keyword('isSimpleObject'), Object, Boolean),
    UnaryExpression(Keyword('isSprintAllowed'), Object, Boolean),
    UnaryExpression(Keyword('isStaminaEnabled'), Object, Boolean),
    UnaryExpression(Keyword('isText'), Config, Boolean),
    UnaryExpression(Keyword('isTouchingGround'), Object, Boolean),
    UnaryExpression(Keyword('isTurnedOut'), Object, Boolean),
    UnaryExpression(Keyword('isUAVConnected'), Object, Boolean),
    UnaryExpression(Keyword('isVehicleCargo'), Object, Object),
    UnaryExpression(Keyword('isWalking'), Object, Boolean),
    UnaryExpression(Keyword('isWeaponDeployed'), Object, Boolean),
    UnaryExpression(Keyword('isWeaponRested'), Object, Boolean),
    UnaryExpression(Keyword('itemCargo'), Object, Array),
    UnaryExpression(Keyword('items'), Object, Array),
    UnaryExpression(Keyword('itemsWithMagazines'), Object, Array),
    UnaryExpression(Keyword('keyImage'), Number, String),
    UnaryExpression(Keyword('keyName'), Number, String),
    UnaryExpression(Keyword('landResult'), Object, String),
    UnaryExpression(Keyword('laserTarget'), Object, Object),
    UnaryExpression(Keyword('lbAdd'), Array, Number),
    UnaryExpression(Keyword('lbClear'), Object, Nothing),
    UnaryExpression(Keyword('lbClear'), Number, Nothing),
    UnaryExpression(Keyword('lbColor'), Array, Array),
    UnaryExpression(Keyword('lbColorRight'), Array, Array),
    UnaryExpression(Keyword('lbCurSel'), Object, Number),
    UnaryExpression(Keyword('lbCurSel'), Number, Number),
    UnaryExpression(Keyword('lbData'), Array, String),
    UnaryExpression(Keyword('lbDelete'), Array, Nothing),
    UnaryExpression(Keyword('lbPicture'), Array, String),
    UnaryExpression(Keyword('lbPictureRight'), Array, String),
    UnaryExpression(Keyword('lbSelection'), Object, Array),
    UnaryExpression(Keyword('lbSetColor'), Array, Nothing),
    UnaryExpression(Keyword('lbSetColorRight'), Array, Nothing),
    UnaryExpression(Keyword('lbSetCurSel'), Array, Nothing),
    UnaryExpression(Keyword('lbSetData'), Array, Nothing),
    UnaryExpression(Keyword('lbSetPicture'), Array, Nothing),
    UnaryExpression(Keyword('lbSetPictureColor'), Array, Nothing),
    UnaryExpression(Keyword('lbSetPictureColorDisabled'), Array, Nothing),
    UnaryExpression(Keyword('lbSetPictureColorSelected'), Array, Nothing),
    UnaryExpression(Keyword('lbSetPictureRight'), Array, Nothing),
    UnaryExpression(Keyword('lbSetSelectColor'), Array, Nothing),
    UnaryExpression(Keyword('lbSetSelectColorRight'), Array, Nothing),
    UnaryExpression(Keyword('lbSetText'), Array, String),
    UnaryExpression(Keyword('lbSetTooltip'), Array, Nothing),
    UnaryExpression(Keyword('lbSetValue'), Array, Nothing),
    UnaryExpression(Keyword('lbSize'), Object, Number),
    UnaryExpression(Keyword('lbSize'), Number, Number),
    UnaryExpression(Keyword('lbSort'), Object, Number),
    UnaryExpression(Keyword('lbSort'), Array, Number),
    UnaryExpression(Keyword('lbSortByValue'), Object, Number),
    UnaryExpression(Keyword('lbText'), Array, String),
    UnaryExpression(Keyword('lbTextRight'), Array, String),
    UnaryExpression(Keyword('lbValue'), Array, Number),
    UnaryExpression(Keyword('leader'), Object, Object),
    UnaryExpression(Keyword('leader'), Object, Object),
    UnaryExpression(Keyword('leader'), Object, Object),
    UnaryExpression(Keyword('leaderboardDeInit'), String, Boolean),
    UnaryExpression(Keyword('leaderboardGetRows'), String, Array),
    UnaryExpression(Keyword('leaderboardInit'), String, Boolean),
    UnaryExpression(Keyword('leaderboardRequestRowsFriends'), String, Boolean),
    UnaryExpression(Keyword('leaderboardRequestRowsGlobal'), Array, Boolean),
    UnaryExpression(Keyword('leaderboardRequestRowsGlobalAroundUser'), Array, Boolean),
    UnaryExpression(Keyword('leaderboardState'), String, Number),
    UnaryExpression(Keyword('leaderboardsRequestUploadScore'), Array, Boolean),
    UnaryExpression(Keyword('leaderboardsRequestUploadScoreKeepBest'), Array, Boolean),
    UnaryExpression(Keyword('lifeState'), Object, String),
    UnaryExpression(Keyword('lightDetachObject'), Object, Nothing),
    UnaryExpression(Keyword('lightIsOn'), Object, String),
    UnaryExpression(Keyword('lineIntersects'), Array, Boolean),
    UnaryExpression(Keyword('lineIntersectsObjs'), Array, Array),
    UnaryExpression(Keyword('lineIntersectsSurfaces'), Array, Array),
    UnaryExpression(Keyword('lineIntersectsWith'), Array, Array),
    UnaryExpression(Keyword('linearConversion'), Array, Number),
    UnaryExpression(Keyword('list'), Object, Array),
    UnaryExpression(Keyword('ln'), Number, Number),
    UnaryExpression(Keyword('lnbAddArray'), Array, Number),
    UnaryExpression(Keyword('lnbAddColumn'), Array, Number),
    UnaryExpression(Keyword('lnbAddRow'), Array, Number),
    UnaryExpression(Keyword('lnbClear'), Object, Nothing),
    UnaryExpression(Keyword('lnbClear'), Number, Nothing),
    UnaryExpression(Keyword('lnbColor'), Array, Array),
    UnaryExpression(Keyword('lnbColorRight'), Array, Array),
    UnaryExpression(Keyword('lnbCurSelRow'), Object, Number),
    UnaryExpression(Keyword('lnbCurSelRow'), Number, Number),
    UnaryExpression(Keyword('lnbData'), Array, String),
    UnaryExpression(Keyword('lnbDeleteColumn'), Array, Nothing),
    UnaryExpression(Keyword('lnbDeleteRow'), Array, Nothing),
    UnaryExpression(Keyword('lnbGetColumnsPosition'), Object, Array),
    UnaryExpression(Keyword('lnbGetColumnsPosition'), Number, Array),
    UnaryExpression(Keyword('lnbPicture'), Array, String),
    UnaryExpression(Keyword('lnbPictureRight'), Array, String),
    UnaryExpression(Keyword('lnbSetColor'), Array, Nothing),
    UnaryExpression(Keyword('lnbSetColorRight'), Array, Nothing),
    UnaryExpression(Keyword('lnbSetCurSelRow'), Array, Nothing),
    UnaryExpression(Keyword('lnbSetData'), Array, Nothing),
    UnaryExpression(Keyword('lnbSetPicture'), Array, Nothing),
    UnaryExpression(Keyword('lnbSetPictureColor'), Array, Nothing),
    UnaryExpression(Keyword('lnbSetPictureColorRight'), Array, Nothing),
    UnaryExpression(Keyword('lnbSetPictureColorSelected'), Array, Nothing),
    UnaryExpression(Keyword('lnbSetPictureColorSelectedRight'), Array, Nothing),
    UnaryExpression(Keyword('lnbSetPictureRight'), Array, Nothing),
    UnaryExpression(Keyword('lnbSetText'), Array, Nothing),
    UnaryExpression(Keyword('lnbSetTextRight'), Array, Nothing),
    UnaryExpression(Keyword('lnbSetValue'), Array, Nothing),
    UnaryExpression(Keyword('lnbSize'), Object, Array),
    UnaryExpression(Keyword('lnbSize'), Number, Array),
    UnaryExpression(Keyword('lnbSort'), Array, Nothing),
    UnaryExpression(Keyword('lnbSortByValue'), Array, Nothing),
    UnaryExpression(Keyword('lnbText'), Array, String),
    UnaryExpression(Keyword('lnbTextRight'), Array, String),
    UnaryExpression(Keyword('lnbValue'), Array, Number),
    UnaryExpression(Keyword('lnbsetColumnsPos'), Array, Nothing),
    UnaryExpression(Keyword('load'), Object, Number),
    UnaryExpression(Keyword('loadAbs'), Object, Number),
    UnaryExpression(Keyword('loadBackpack'), Object, Number),
    UnaryExpression(Keyword('loadFile'), String, String),
    UnaryExpression(Keyword('loadUniform'), Object, Number),
    UnaryExpression(Keyword('loadVest'), Object, Number),
    UnaryExpression(Keyword('local'), Object, Boolean),
    UnaryExpression(Keyword('local'), Object, Boolean),
    UnaryExpression(Keyword('localize'), String, String),
    UnaryExpression(Keyword('locationPosition'), Object, Array),
    UnaryExpression(Keyword('lockIdentity'), Object, Boolean),
    UnaryExpression(Keyword('locked'), Object, Number),
    UnaryExpression(Keyword('lockedDriver'), Object, Boolean),
    UnaryExpression(Keyword('log'), Number, Number),
    UnaryExpression(Keyword('logNetwork'), Array, Number),
    UnaryExpression(Keyword('logNetworkTerminate'), Number, Nothing),
    UnaryExpression(Keyword('magazineCargo'), Object, Array),
    UnaryExpression(Keyword('magazines'), Object, Array),
    UnaryExpression(Keyword('magazinesAllTurrets'), Object, Array),
    UnaryExpression(Keyword('magazinesAmmo'), Object, Array),
    UnaryExpression(Keyword('magazinesAmmoCargo'), Object, Array),
    UnaryExpression(Keyword('magazinesAmmoFull'), Object, Array),
    UnaryExpression(Keyword('magazinesDetail'), Object, Array),
    UnaryExpression(Keyword('magazinesDetailBackpack'), Object, Array),
    UnaryExpression(Keyword('magazinesDetailUniform'), Object, Array),
    UnaryExpression(Keyword('magazinesDetailVest'), Object, Array),
    UnaryExpression(Keyword('mapAnimAdd'), Array, Nothing),
    UnaryExpression(Keyword('mapCenterOnCamera'), Object, Array),
    UnaryExpression(Keyword('mapGridPosition'), Object, String),
    UnaryExpression(Keyword('mapGridPosition'), Array, String),
    UnaryExpression(Keyword('markerAlpha'), String, Number),
    UnaryExpression(Keyword('markerBrush'), String, String),
    UnaryExpression(Keyword('markerColor'), String, String),
    UnaryExpression(Keyword('markerDir'), String, Number),
    UnaryExpression(Keyword('markerPos'), String, Array),
    UnaryExpression(Keyword('markerShape'), String, String),
    UnaryExpression(Keyword('markerSize'), String, Array),
    UnaryExpression(Keyword('markerText'), String, String),
    UnaryExpression(Keyword('markerType'), String, String),
    UnaryExpression(Keyword('members'), Object, Array),
    UnaryExpression(Keyword('menuAction'), Array, String),
    UnaryExpression(Keyword('menuAdd'), Array, Number),
    UnaryExpression(Keyword('menuChecked'), Array, Boolean),
    UnaryExpression(Keyword('menuCollapse'), Array, Nothing),
    UnaryExpression(Keyword('menuData'), Array, String),
    UnaryExpression(Keyword('menuDelete'), Array, Nothing),
    UnaryExpression(Keyword('menuEnable'), Array, Nothing),
    UnaryExpression(Keyword('menuEnabled'), Array, Boolean),
    UnaryExpression(Keyword('menuExpand'), Array, Nothing),
    UnaryExpression(Keyword('menuHover'), Object, Array),
    UnaryExpression(Keyword('menuHover'), Number, Array),
    UnaryExpression(Keyword('menuPicture'), Array, String),
    UnaryExpression(Keyword('menuSetAction'), Array, Nothing),
    UnaryExpression(Keyword('menuSetCheck'), Array, Nothing),
    UnaryExpression(Keyword('menuSetData'), Array, Nothing),
    UnaryExpression(Keyword('menuSetPicture'), Array, Nothing),
    UnaryExpression(Keyword('menuSetValue'), Array, Nothing),
    UnaryExpression(Keyword('menuShortcut'), Array, Number),
    UnaryExpression(Keyword('menuShortcutText'), Array, String),
    UnaryExpression(Keyword('menuSize'), Array, Number),
    UnaryExpression(Keyword('menuSort'), Array, Nothing),
    UnaryExpression(Keyword('menuText'), Array, String),
    UnaryExpression(Keyword('menuURL'), Array, String),
    UnaryExpression(Keyword('menuValue'), Array, Number),
    UnaryExpression(Keyword('mineActive'), Object, Boolean),
    UnaryExpression(Keyword('modParams'), Array, Array),
    UnaryExpression(Keyword('moonPhase'), Array, Number),
    UnaryExpression(Keyword('morale'), Object, Number),
    UnaryExpression(Keyword('move3DENCamera'), Array, Nothing),
    UnaryExpression(Keyword('moveOut'), Object, Nothing),
    UnaryExpression(Keyword('moveTime'), Object, Number),
    UnaryExpression(Keyword('moveToCompleted'), Object, Boolean),
    UnaryExpression(Keyword('moveToFailed'), Object, Boolean),
    UnaryExpression(Keyword('name'), Object, String),
    UnaryExpression(Keyword('name'), Object, String),
    UnaryExpression(Keyword('nameSound'), Object, String),
    UnaryExpression(Keyword('nearestBuilding'), Object, Object),
    UnaryExpression(Keyword('nearestBuilding'), Array, Object),
    UnaryExpression(Keyword('nearestLocation'), Array, Object),
    UnaryExpression(Keyword('nearestLocationWithDubbing'), Array, Object),
    UnaryExpression(Keyword('nearestLocations'), Array, Array),
    UnaryExpression(Keyword('nearestObject'), Array, Object),
    UnaryExpression(Keyword('nearestObjects'), Array, Array),
    UnaryExpression(Keyword('nearestTerrainObjects'), Array, Array),
    UnaryExpression(Keyword('needReload'), Object, Number),
    UnaryExpression(Keyword('netId'), Object, String),
    UnaryExpression(Keyword('netId'), Object, String),
    UnaryExpression(Keyword('nextMenuItemIndex'), Object, Number),
    UnaryExpression(Keyword('not'), Boolean, Boolean),
    UnaryExpression(Keyword('numberOfEnginesRTD'), Object, Number),
    UnaryExpression(Keyword('numberToDate'), Array, Array),
    UnaryExpression(Keyword('objectCurators'), Object, Array),
    UnaryExpression(Keyword('objectFromNetId'), String, Object),
    UnaryExpression(Keyword('objectParent'), Object, Object),
    UnaryExpression(Keyword('onBriefingGroup'), String, Nothing),
    UnaryExpression(Keyword('onBriefingNotes'), String, Nothing),
    UnaryExpression(Keyword('onBriefingPlan'), String, Nothing),
    UnaryExpression(Keyword('onBriefingTeamSwitch'), String, Nothing),
    UnaryExpression(Keyword('onCommandModeChanged'), Code, Nothing),
    UnaryExpression(Keyword('onCommandModeChanged'), String, Nothing),
    UnaryExpression(Keyword('onEachFrame'), Code, Nothing),
    UnaryExpression(Keyword('onEachFrame'), String, Nothing),
    UnaryExpression(Keyword('onGroupIconClick'), Code, Nothing),
    UnaryExpression(Keyword('onGroupIconClick'), String, Nothing),
    UnaryExpression(Keyword('onGroupIconOverEnter'), Code, Nothing),
    UnaryExpression(Keyword('onGroupIconOverEnter'), String, Nothing),
    UnaryExpression(Keyword('onGroupIconOverLeave'), Code, Nothing),
    UnaryExpression(Keyword('onGroupIconOverLeave'), String, Nothing),
    UnaryExpression(Keyword('onHCGroupSelectionChanged'), Code, Nothing),
    UnaryExpression(Keyword('onHCGroupSelectionChanged'), String, Nothing),
    UnaryExpression(Keyword('onMapSingleClick'), Code, Nothing),
    UnaryExpression(Keyword('onMapSingleClick'), String, Nothing),
    UnaryExpression(Keyword('onPlayerConnected'), Code, Nothing),
    UnaryExpression(Keyword('onPlayerConnected'), String, Nothing),
    UnaryExpression(Keyword('onPlayerDisconnected'), Code, Nothing),
    UnaryExpression(Keyword('onPlayerDisconnected'), String, Nothing),
    UnaryExpression(Keyword('onPreloadFinished'), Code, Nothing),
    UnaryExpression(Keyword('onPreloadFinished'), String, Nothing),
    UnaryExpression(Keyword('onPreloadStarted'), Code, Nothing),
    UnaryExpression(Keyword('onPreloadStarted'), String, Nothing),
    UnaryExpression(Keyword('onTeamSwitch'), Code, Nothing),
    UnaryExpression(Keyword('onTeamSwitch'), String, Nothing),
    UnaryExpression(Keyword('openDLCPage'), Number, Boolean),
    UnaryExpression(Keyword('openMap'), Array, Boolean),
    UnaryExpression(Keyword('openMap'), Boolean, Boolean),
    UnaryExpression(Keyword('openYoutubeVideo'), String, Boolean),
    UnaryExpression(Keyword('owner'), Object, Number),
    UnaryExpression(Keyword('param'), Array, Nothing),
    UnaryExpression(Keyword('params'), Array, Boolean),
    UnaryExpression(Keyword('parseNumber'), String, Number),
    UnaryExpression(Keyword('parseNumber'), Boolean, Number),
    UnaryExpression(Keyword('parseSimpleArray'), String, Array),
    UnaryExpression(Keyword('parseText'), String, String),
    UnaryExpression(Keyword('pickWeaponPool'), Object, Nothing),
    UnaryExpression(Keyword('pitch'), Object, String),
    UnaryExpression(Keyword('playMission'), Array, Nothing),
    UnaryExpression(Keyword('playMusic'), String, Nothing),
    UnaryExpression(Keyword('playMusic'), Array, Nothing),
    UnaryExpression(Keyword('playScriptedMission'), Array, Nothing),
    UnaryExpression(Keyword('playSound'), String, Nothing),
    UnaryExpression(Keyword('playSound'), Array, Nothing),
    UnaryExpression(Keyword('playSound3D'), Array, Nothing),
    UnaryExpression(Keyword('playableSlotsNumber'), Object, Number),
    UnaryExpression(Keyword('playersNumber'), Object, Number),
    UnaryExpression(Keyword('position'), Object, Array),
    UnaryExpression(Keyword('position'), Object, Array),
    UnaryExpression(Keyword('positionCameraToWorld'), Array, Array),
    UnaryExpression(Keyword('ppEffectCommitted'), String, Boolean),
    UnaryExpression(Keyword('ppEffectCommitted'), Number, Boolean),
    UnaryExpression(Keyword('ppEffectCreate'), Array, Nothing),
    UnaryExpression(Keyword('ppEffectDestroy'), Number, Nothing),
    UnaryExpression(Keyword('ppEffectDestroy'), Array, Nothing),
    UnaryExpression(Keyword('ppEffectEnabled'), Number, Boolean),
    UnaryExpression(Keyword('precision'), Object, Number),
    UnaryExpression(Keyword('preloadCamera'), Array, Boolean),
    UnaryExpression(Keyword('preloadSound'), String, Boolean),
    UnaryExpression(Keyword('preloadTitleObj'), Array, Boolean),
    UnaryExpression(Keyword('preloadTitleRsc'), Array, Boolean),
    UnaryExpression(Keyword('preprocessFile'), String, String),
    UnaryExpression(Keyword('preprocessFileLineNumbers'), String, String),
    UnaryExpression(Keyword('primaryWeapon'), Object, String),
    UnaryExpression(Keyword('primaryWeaponItems'), Object, Array),
    UnaryExpression(Keyword('primaryWeaponMagazine'), Object, Array),
    UnaryExpression(Keyword('priority'), Object, Number),
    UnaryExpression(Keyword('private'), String, Nothing),
    UnaryExpression(Keyword('private'), Array, Nothing),
    UnaryExpression(Keyword('processDiaryLink'), String, Nothing),
    UnaryExpression(Keyword('progressLoadingScreen'), Number, Nothing),
    UnaryExpression(Keyword('progressPosition'), Object, Number),
    UnaryExpression(Keyword('publicVariable'), String, Nothing),
    UnaryExpression(Keyword('publicVariableServer'), String, Nothing),
    UnaryExpression(Keyword('putWeaponPool'), Object, Nothing),
    UnaryExpression(Keyword('queryItemsPool'), String, Number),
    UnaryExpression(Keyword('queryMagazinePool'), String, Number),
    UnaryExpression(Keyword('queryWeaponPool'), String, Number),
    UnaryExpression(Keyword('rad'), Number, Number),
    UnaryExpression(Keyword('radioChannelCreate'), Array, Number),
    UnaryExpression(Keyword('random'), Array, Number),
    UnaryExpression(Keyword('random'), Number, Number),
    UnaryExpression(Keyword('rank'), Object, String),
    UnaryExpression(Keyword('rankId'), Object, Number),
    UnaryExpression(Keyword('rating'), Object, Number),
    UnaryExpression(Keyword('rectangular'), Object, Boolean),
    UnaryExpression(Keyword('registeredTasks'), Object, Array),
    UnaryExpression(Keyword('reload'), Object, Nothing),
    UnaryExpression(Keyword('reloadEnabled'), Object, Boolean),
    UnaryExpression(Keyword('remoteExec'), Array, Nothing),
    UnaryExpression(Keyword('remoteExecCall'), Array, Nothing),
    UnaryExpression(Keyword('remove3DENConnection'), Array, Nothing),
    UnaryExpression(Keyword('remove3DENEventHandler'), Array, Nothing),
    UnaryExpression(Keyword('remove3DENLayer'), Number, Boolean),
    UnaryExpression(Keyword('removeAll3DENEventHandlers'), String, Nothing),
    UnaryExpression(Keyword('removeAllActions'), Object, Nothing),
    UnaryExpression(Keyword('removeAllAssignedItems'), Object, Nothing),
    UnaryExpression(Keyword('removeAllContainers'), Object, Nothing),
    UnaryExpression(Keyword('removeAllCuratorAddons'), Object, Nothing),
    UnaryExpression(Keyword('removeAllCuratorCameraAreas'), Object, Nothing),
    UnaryExpression(Keyword('removeAllCuratorEditingAreas'), Object, Nothing),
    UnaryExpression(Keyword('removeAllHandgunItems'), Object, Nothing),
    UnaryExpression(Keyword('removeAllItems'), Object, Nothing),
    UnaryExpression(Keyword('removeAllItemsWithMagazines'), Object, Nothing),
    UnaryExpression(Keyword('removeAllMissionEventHandlers'), String, Nothing),
    UnaryExpression(Keyword('removeAllMusicEventHandlers'), String, Nothing),
    UnaryExpression(Keyword('removeAllOwnedMines'), Object, Nothing),
    UnaryExpression(Keyword('removeAllPrimaryWeaponItems'), Object, Nothing),
    UnaryExpression(Keyword('removeAllWeapons'), Object, Nothing),
    UnaryExpression(Keyword('removeBackpack'), Object, Nothing),
    UnaryExpression(Keyword('removeBackpackGlobal'), Object, Nothing),
    UnaryExpression(Keyword('removeFromRemainsCollector'), Array, Nothing),
    UnaryExpression(Keyword('removeGoggles'), Object, Nothing),
    UnaryExpression(Keyword('removeHeadgear'), Object, Nothing),
    UnaryExpression(Keyword('removeMissionEventHandler'), Array, Nothing),
    UnaryExpression(Keyword('removeMusicEventHandler'), Array, Nothing),
    UnaryExpression(Keyword('removeSwitchableUnit'), Object, Nothing),
    UnaryExpression(Keyword('removeUniform'), Object, Nothing),
    UnaryExpression(Keyword('removeVest'), Object, Nothing),
    UnaryExpression(Keyword('requiredVersion'), String, Boolean),
    UnaryExpression(Keyword('resetSubgroupDirection'), Object, Nothing),
    UnaryExpression(Keyword('resources'), Object, Array),
    UnaryExpression(Keyword('restartEditorCamera'), Object, Nothing),
    UnaryExpression(Keyword('reverse'), Array, Nothing),
    UnaryExpression(Keyword('roadAt'), Object, Object),
    UnaryExpression(Keyword('roadAt'), Array, Object),
    UnaryExpression(Keyword('roadsConnectedTo'), Object, Array),
    UnaryExpression(Keyword('roleDescription'), Object, String),
    UnaryExpression(Keyword('ropeAttachEnabled'), Object, Boolean),
    UnaryExpression(Keyword('ropeAttachedObjects'), Object, Array),
    UnaryExpression(Keyword('ropeAttachedTo'), Object, Object),
    UnaryExpression(Keyword('ropeCreate'), Array, Object),
    UnaryExpression(Keyword('ropeCut'), Array, Nothing),
    UnaryExpression(Keyword('ropeDestroy'), Object, Nothing),
    UnaryExpression(Keyword('ropeEndPosition'), Object, Array),
    UnaryExpression(Keyword('ropeLength'), Object, Number),
    UnaryExpression(Keyword('ropeUnwind'), Array, Nothing),
    UnaryExpression(Keyword('ropeUnwound'), Object, Boolean),
    UnaryExpression(Keyword('ropes'), Object, Array),
    UnaryExpression(Keyword('rotorsForcesRTD'), Object, Array),
    UnaryExpression(Keyword('rotorsRpmRTD'), Object, Array),
    UnaryExpression(Keyword('round'), Number, Number),
    UnaryExpression(Keyword('save3DENInventory'), Array, Nothing),
    UnaryExpression(Keyword('saveOverlay'), Object, Nothing),
    UnaryExpression(Keyword('saveVar'), String, Nothing),
    UnaryExpression(Keyword('scopeName'), String, Nothing),
    UnaryExpression(Keyword('score'), Object, Number),
    UnaryExpression(Keyword('scoreSide'), Object, Number),
    UnaryExpression(Keyword('screenToWorld'), Array, Array),
    UnaryExpression(Keyword('screenshot'), String, Boolean),
    UnaryExpression(Keyword('scriptDone'), Script, Boolean),
    UnaryExpression(Keyword('scriptName'), String, Nothing),
    UnaryExpression(Keyword('scudState'), Object, Number),
    UnaryExpression(Keyword('secondaryWeapon'), Object, String),
    UnaryExpression(Keyword('secondaryWeaponItems'), Object, Array),
    UnaryExpression(Keyword('secondaryWeaponMagazine'), Object, Array),
    UnaryExpression(Keyword('selectBestPlaces'), Array, Array),
    UnaryExpression(Keyword('selectMax'), Array, Nothing),
    UnaryExpression(Keyword('selectMin'), Array, Nothing),
    UnaryExpression(Keyword('selectPlayer'), Object, Nothing),
    UnaryExpression(Keyword('selectRandom'), Array, Nothing),
    UnaryExpression(Keyword('selectedEditorObjects'), Object, Nothing),
    UnaryExpression(Keyword('selectionNames'), Object, Array),
    UnaryExpression(Keyword('sendAUMessage'), Array, Nothing),
    UnaryExpression(Keyword('sendUDPMessage'), Array, Boolean),
    UnaryExpression(Keyword('serverCommand'), String, Boolean),
    UnaryExpression(Keyword('serverCommandAvailable'), String, Boolean),
    UnaryExpression(Keyword('serverCommandExecutable'), String, Boolean),
    UnaryExpression(Keyword('set3DENAttributes'), Array, Boolean),
    UnaryExpression(Keyword('set3DENGrid'), Array, Nothing),
    UnaryExpression(Keyword('set3DENIconsVisible'), Array, Nothing),
    UnaryExpression(Keyword('set3DENLinesVisible'), Array, Nothing),
    UnaryExpression(Keyword('set3DENMissionAttributes'), Array, Nothing),
    UnaryExpression(Keyword('set3DENModelsVisible'), Array, Nothing),
    UnaryExpression(Keyword('set3DENSelected'), Array, Nothing),
    UnaryExpression(Keyword('setAccTime'), Number, Nothing),
    UnaryExpression(Keyword('setAperture'), Number, Nothing),
    UnaryExpression(Keyword('setApertureNew'), Array, Nothing),
    UnaryExpression(Keyword('setArmoryPoints'), Number, Nothing),
    UnaryExpression(Keyword('setCamShakeDefParams'), Array, Nothing),
    UnaryExpression(Keyword('setCamShakeParams'), Array, Nothing),
    UnaryExpression(Keyword('setCompassOscillation'), Array, Nothing),
    UnaryExpression(Keyword('setCurrentChannel'), Number, Boolean),
    UnaryExpression(Keyword('setDate'), Array, Nothing),
    UnaryExpression(Keyword('setDefaultCamera'), Array, Nothing),
    UnaryExpression(Keyword('setDetailMapBlendPars'), Array, Nothing),
    UnaryExpression(Keyword('setGroupIconsSelectable'), Boolean, Nothing),
    UnaryExpression(Keyword('setGroupIconsVisible'), Array, Nothing),
    UnaryExpression(Keyword('setHUDMovementLevels'), Array, Nothing),
    UnaryExpression(Keyword('setHorizonParallaxCoef'), Number, Nothing),
    UnaryExpression(Keyword('setLocalWindParams'), Array, Nothing),
    UnaryExpression(Keyword('setMousePosition'), Array, Nothing),
    UnaryExpression(Keyword('setMusicEventHandler'), Array, Nothing),
    UnaryExpression(Keyword('setObjectViewDistance'), Number, Nothing),
    UnaryExpression(Keyword('setObjectViewDistance'), Array, Nothing),
    UnaryExpression(Keyword('setPlayable'), Object, Nothing),
    UnaryExpression(Keyword('setPlayerRespawnTime'), Number, Nothing),
    UnaryExpression(Keyword('setShadowDistance'), Number, Nothing),
    UnaryExpression(Keyword('setSimulWeatherLayers'), Number, Nothing),
    UnaryExpression(Keyword('setStaminaScheme'), String, Nothing),
    UnaryExpression(Keyword('setStatValue'), Array, Boolean),
    UnaryExpression(Keyword('setSystemOfUnits'), Number, Nothing),
    UnaryExpression(Keyword('setTerrainGrid'), Number, Nothing),
    UnaryExpression(Keyword('setTimeMultiplier'), Number, Nothing),
    UnaryExpression(Keyword('setTrafficDensity'), Array, Nothing),
    UnaryExpression(Keyword('setTrafficDistance'), Number, Nothing),
    UnaryExpression(Keyword('setTrafficGap'), Array, Nothing),
    UnaryExpression(Keyword('setTrafficSpeed'), Array, Nothing),
    UnaryExpression(Keyword('setViewDistance'), Number, Nothing),
    UnaryExpression(Keyword('setWind'), Array, Nothing),
    UnaryExpression(Keyword('setWindDir'), Array, Nothing),
    UnaryExpression(Keyword('showChat'), Boolean, Nothing),
    UnaryExpression(Keyword('showCinemaBorder'), Boolean, Nothing),
    UnaryExpression(Keyword('showCommandingMenu'), String, Nothing),
    UnaryExpression(Keyword('showCompass'), Boolean, Nothing),
    UnaryExpression(Keyword('showCuratorCompass'), Boolean, Nothing),
    UnaryExpression(Keyword('showGps'), Boolean, Nothing),
    UnaryExpression(Keyword('showHUD'), Boolean, Nothing),
    UnaryExpression(Keyword('showHUD'), Array, Nothing),
    UnaryExpression(Keyword('showMap'), Boolean, Nothing),
    UnaryExpression(Keyword('showPad'), Boolean, Nothing),
    UnaryExpression(Keyword('showRadio'), Boolean, Nothing),
    UnaryExpression(Keyword('showScoretable'), Number, Nothing),
    UnaryExpression(Keyword('showSubtitles'), Boolean, Boolean),
    UnaryExpression(Keyword('showUAVFeed'), Boolean, Nothing),
    UnaryExpression(Keyword('showWarrant'), Boolean, Nothing),
    UnaryExpression(Keyword('showWatch'), Boolean, Nothing),
    UnaryExpression(Keyword('showWaypoints'), Boolean, Nothing),
    UnaryExpression(Keyword('side'), Object, Object),
    UnaryExpression(Keyword('side'), Object, Object),
    UnaryExpression(Keyword('side'), Object, Object),
    UnaryExpression(Keyword('simpleTasks'), Object, Array),
    UnaryExpression(Keyword('simulCloudDensity'), Array, Number),
    UnaryExpression(Keyword('simulCloudOcclusion'), Array, Number),
    UnaryExpression(Keyword('simulInClouds'), Array, Boolean),
    UnaryExpression(Keyword('simulationEnabled'), Object, Boolean),
    UnaryExpression(Keyword('sin'), Number, Number),
    UnaryExpression(Keyword('size'), Object, Array),
    UnaryExpression(Keyword('sizeOf'), String, Number),
    UnaryExpression(Keyword('skill'), Object, Number),
    UnaryExpression(Keyword('skipTime'), Number, Nothing),
    UnaryExpression(Keyword('sleep'), Number, Nothing),
    UnaryExpression(Keyword('sliderPosition'), Object, Number),
    UnaryExpression(Keyword('sliderPosition'), Number, Number),
    UnaryExpression(Keyword('sliderRange'), Object, Array),
    UnaryExpression(Keyword('sliderRange'), Number, Array),
    UnaryExpression(Keyword('sliderSetPosition'), Array, Nothing),
    UnaryExpression(Keyword('sliderSetRange'), Array, Nothing),
    UnaryExpression(Keyword('sliderSetSpeed'), Array, Nothing),
    UnaryExpression(Keyword('sliderSpeed'), Object, Array),
    UnaryExpression(Keyword('sliderSpeed'), Number, Array),
    UnaryExpression(Keyword('someAmmo'), Object, Boolean),
    UnaryExpression(Keyword('speaker'), Object, String),
    UnaryExpression(Keyword('speed'), Object, Number),
    UnaryExpression(Keyword('speedMode'), Object, String),
    UnaryExpression(Keyword('speedMode'), Object, String),
    UnaryExpression(Keyword('sqrt'), Number, Number),
    UnaryExpression(Keyword('squadParams'), Object, Array),
    UnaryExpression(Keyword('stance'), Object, String),
    UnaryExpression(Keyword('startLoadingScreen'), Array, Nothing),
    UnaryExpression(Keyword('stopEngineRTD'), Object, Nothing),
    UnaryExpression(Keyword('stopped'), Object, Boolean),
    UnaryExpression(Keyword('str'), Type, String),
    UnaryExpression(Keyword('supportInfo'), String, Array),
    UnaryExpression(Keyword('surfaceIsWater'), Array, Boolean),
    UnaryExpression(Keyword('surfaceNormal'), Array, Array),
    UnaryExpression(Keyword('surfaceType'), Array, String),
    UnaryExpression(Keyword('switch'), Type, SwitchType),
    UnaryExpression(Keyword('switchCamera'), Object, Nothing),
    UnaryExpression(Keyword('synchronizedObjects'), Object, Array),
    UnaryExpression(Keyword('synchronizedTriggers'), Array, Array),
    UnaryExpression(Keyword('synchronizedWaypoints'), Object, Array),
    UnaryExpression(Keyword('synchronizedWaypoints'), Array, Array),
    UnaryExpression(Keyword('systemChat'), String, Nothing),
    UnaryExpression(Keyword('tan'), Number, Number),
    UnaryExpression(Keyword('taskAlwaysVisible'), Object, Boolean),
    UnaryExpression(Keyword('taskChildren'), Object, Array),
    UnaryExpression(Keyword('taskCompleted'), Object, Boolean),
    UnaryExpression(Keyword('taskCustomData'), Object, Array),
    UnaryExpression(Keyword('taskDescription'), Object, Array),
    UnaryExpression(Keyword('taskDestination'), Object, Array),
    UnaryExpression(Keyword('taskHint'), Array, Nothing),
    UnaryExpression(Keyword('taskMarkerOffset'), Object, Array),
    UnaryExpression(Keyword('taskParent'), Object, Object),
    UnaryExpression(Keyword('taskResult'), Object, Array),
    UnaryExpression(Keyword('taskState'), Object, String),
    UnaryExpression(Keyword('taskType'), Object, String),
    UnaryExpression(Keyword('teamMember'), Object, Object),
    UnaryExpression(Keyword('teamName'), Object, String),
    UnaryExpression(Keyword('teamType'), Object, String),
    UnaryExpression(Keyword('terminate'), Script, Nothing),
    UnaryExpression(Keyword('terrainIntersect'), Array, Boolean),
    UnaryExpression(Keyword('terrainIntersectASL'), Array, Boolean),
    UnaryExpression(Keyword('terrainIntersectAtASL'), Array, Array),
    UnaryExpression(Keyword('text'), String, String),
    UnaryExpression(Keyword('text'), Object, String),
    UnaryExpression(Keyword('textLog'), Type, Nothing),
    UnaryExpression(Keyword('textLogFormat'), Array, Nothing),
    UnaryExpression(Keyword('tg'), Number, Number),
    UnaryExpression(Keyword('throw'), Type, Nothing),
    UnaryExpression(Keyword('titleCut'), Array, Nothing),
    UnaryExpression(Keyword('titleFadeOut'), Number, Nothing),
    UnaryExpression(Keyword('titleObj'), Array, Nothing),
    UnaryExpression(Keyword('titleRsc'), Array, Nothing),
    UnaryExpression(Keyword('titleText'), Array, Nothing),
    UnaryExpression(Keyword('toArray'), String, Array),
    UnaryExpression(Keyword('toLower'), String, String),
    UnaryExpression(Keyword('toString'), Array, String),
    UnaryExpression(Keyword('toUpper'), String, String),
    UnaryExpression(Keyword('triggerActivated'), Object, Boolean),
    UnaryExpression(Keyword('triggerActivation'), Object, Array),
    UnaryExpression(Keyword('triggerArea'), Object, Array),
    UnaryExpression(Keyword('triggerAttachedVehicle'), Object, Object),
    UnaryExpression(Keyword('triggerStatements'), Object, Array),
    UnaryExpression(Keyword('triggerText'), Object, String),
    UnaryExpression(Keyword('triggerTimeout'), Object, Array),
    UnaryExpression(Keyword('triggerTimeoutCurrent'), Object, Number),
    UnaryExpression(Keyword('triggerType'), Object, String),
    UnaryExpression(Keyword('try'), Code, TryType),
    UnaryExpression(Keyword('tvAdd'), Array, Number),
    UnaryExpression(Keyword('tvClear'), Number, Nothing),
    UnaryExpression(Keyword('tvClear'), Object, Nothing),
    UnaryExpression(Keyword('tvCollapse'), Array, Nothing),
    UnaryExpression(Keyword('tvCollapseAll'), Number, Nothing),
    UnaryExpression(Keyword('tvCollapseAll'), Object, Nothing),
    UnaryExpression(Keyword('tvCount'), Array, Number),
    UnaryExpression(Keyword('tvCurSel'), Number, Array),
    UnaryExpression(Keyword('tvCurSel'), Object, Array),
    UnaryExpression(Keyword('tvData'), Array, String),
    UnaryExpression(Keyword('tvDelete'), Array, Nothing),
    UnaryExpression(Keyword('tvExpand'), Array, Nothing),
    UnaryExpression(Keyword('tvExpandAll'), Number, Nothing),
    UnaryExpression(Keyword('tvExpandAll'), Object, Nothing),
    UnaryExpression(Keyword('tvPicture'), Array, String),
    UnaryExpression(Keyword('tvPictureRight'), Array, String),
    UnaryExpression(Keyword('tvSetCurSel'), Array, Nothing),
    UnaryExpression(Keyword('tvSetData'), Array, Nothing),
    UnaryExpression(Keyword('tvSetPicture'), Array, Nothing),
    UnaryExpression(Keyword('tvSetPictureColor'), Array, Nothing),
    UnaryExpression(Keyword('tvSetPictureRight'), Array, Nothing),
    UnaryExpression(Keyword('tvSetPictureRightColor'), Array, Nothing),
    UnaryExpression(Keyword('tvSetText'), Array, String),
    UnaryExpression(Keyword('tvSetTooltip'), Array, Nothing),
    UnaryExpression(Keyword('tvSetValue'), Array, Nothing),
    UnaryExpression(Keyword('tvSort'), Array, Nothing),
    UnaryExpression(Keyword('tvSortByValue'), Array, Nothing),
    UnaryExpression(Keyword('tvText'), Array, String),
    UnaryExpression(Keyword('tvTooltip'), Array, String),
    UnaryExpression(Keyword('tvValue'), Array, Number),
    UnaryExpression(Keyword('type'), Object, String),
    UnaryExpression(Keyword('type'), Object, String),
    UnaryExpression(Keyword('typeName'), Type, String),
    UnaryExpression(Keyword('typeOf'), Object, String),
    UnaryExpression(Keyword('uisleep'), Number, Nothing),
    UnaryExpression(Keyword('unassignCurator'), Object, Nothing),
    UnaryExpression(Keyword('unassignTeam'), Object, Nothing),
    UnaryExpression(Keyword('unassignVehicle'), Object, Nothing),
    UnaryExpression(Keyword('underwater'), Object, Boolean),
    UnaryExpression(Keyword('uniform'), Object, String),
    UnaryExpression(Keyword('uniformContainer'), Object, Object),
    UnaryExpression(Keyword('uniformItems'), Object, Array),
    UnaryExpression(Keyword('uniformMagazines'), Object, Array),
    UnaryExpression(Keyword('unitAddons'), String, Array),
    UnaryExpression(Keyword('unitAimPosition'), Object, Array),
    UnaryExpression(Keyword('unitAimPositionVisual'), Object, Array),
    UnaryExpression(Keyword('unitBackpack'), Object, Object),
    UnaryExpression(Keyword('unitIsUAV'), Object, Boolean),
    UnaryExpression(Keyword('unitPos'), Object, String),
    UnaryExpression(Keyword('unitReady'), Object, Boolean),
    UnaryExpression(Keyword('unitReady'), Array, Boolean),
    UnaryExpression(Keyword('unitRecoilCoefficient'), Object, Number),
    UnaryExpression(Keyword('units'), Object, Array),
    UnaryExpression(Keyword('units'), Object, Array),
    UnaryExpression(Keyword('unlockAchievement'), String, Boolean),
    UnaryExpression(Keyword('updateObjectTree'), Object, Nothing),
    UnaryExpression(Keyword('useAIOperMapObstructionTest'), Boolean, Nothing),
    UnaryExpression(Keyword('useAISteeringComponent'), Boolean, Nothing),
    UnaryExpression(Keyword('vectorDir'), Object, Array),
    UnaryExpression(Keyword('vectorDirVisual'), Object, Array),
    UnaryExpression(Keyword('vectorMagnitude'), Array, Number),
    UnaryExpression(Keyword('vectorMagnitudeSqr'), Array, Number),
    UnaryExpression(Keyword('vectorNormalized'), Array, Array),
    UnaryExpression(Keyword('vectorUp'), Object, Array),
    UnaryExpression(Keyword('vectorUpVisual'), Object, Array),
    UnaryExpression(Keyword('vehicle'), Object, Object),
    UnaryExpression(Keyword('vehicleCargoEnabled'), Object, Boolean),
    UnaryExpression(Keyword('vehicleVarName'), Object, String),
    UnaryExpression(Keyword('velocity'), Object, Array),
    UnaryExpression(Keyword('velocityModelSpace'), Object, Array),
    UnaryExpression(Keyword('verifySignature'), String, Boolean),
    UnaryExpression(Keyword('vest'), Object, String),
    UnaryExpression(Keyword('vestContainer'), Object, Object),
    UnaryExpression(Keyword('vestItems'), Object, Array),
    UnaryExpression(Keyword('vestMagazines'), Object, Array),
    UnaryExpression(Keyword('visiblePosition'), Object, Array),
    UnaryExpression(Keyword('visiblePositionASL'), Object, Array),
    UnaryExpression(Keyword('waitUntil'), Code, Nothing),
    UnaryExpression(Keyword('waypointAttachedObject'), Array, Object),
    UnaryExpression(Keyword('waypointAttachedVehicle'), Array, Object),
    UnaryExpression(Keyword('waypointBehaviour'), Array, String),
    UnaryExpression(Keyword('waypointCombatMode'), Array, String),
    UnaryExpression(Keyword('waypointCompletionRadius'), Array, Number),
    UnaryExpression(Keyword('waypointDescription'), Array, String),
    UnaryExpression(Keyword('waypointForceBehaviour'), Array, Boolean),
    UnaryExpression(Keyword('waypointFormation'), Array, String),
    UnaryExpression(Keyword('waypointHousePosition'), Array, Number),
    UnaryExpression(Keyword('waypointLoiterRadius'), Array, Number),
    UnaryExpression(Keyword('waypointLoiterType'), Array, String),
    UnaryExpression(Keyword('waypointName'), Array, String),
    UnaryExpression(Keyword('waypointPosition'), Array, Array),
    UnaryExpression(Keyword('waypointScript'), Array, String),
    UnaryExpression(Keyword('waypointShow'), Array, String),
    UnaryExpression(Keyword('waypointSpeed'), Array, String),
    UnaryExpression(Keyword('waypointStatements'), Array, Array),
    UnaryExpression(Keyword('waypointTimeout'), Array, Array),
    UnaryExpression(Keyword('waypointTimeoutCurrent'), Object, Number),
    UnaryExpression(Keyword('waypointType'), Array, String),
    UnaryExpression(Keyword('waypointVisible'), Array, Number),
    UnaryExpression(Keyword('waypoints'), Object, Array),
    UnaryExpression(Keyword('waypoints'), Object, Array),
    UnaryExpression(Keyword('waypointsEnabledUAV'), Object, Boolean),
    UnaryExpression(Keyword('weaponCargo'), Object, Array),
    UnaryExpression(Keyword('weaponInertia'), Object, Array),
    UnaryExpression(Keyword('weaponLowered'), Object, Boolean),
    UnaryExpression(Keyword('weaponState'), Object, Array),
    UnaryExpression(Keyword('weaponState'), Array, Array),
    UnaryExpression(Keyword('weapons'), Object, Array),
    UnaryExpression(Keyword('weaponsItems'), Object, Array),
    UnaryExpression(Keyword('weaponsItemsCargo'), Object, Array),
    UnaryExpression(Keyword('weightRTD'), Object, Array),
    UnaryExpression(Keyword('while'), Code, WhileType),
    UnaryExpression(Keyword('wingsForcesRTD'), Object, Array),
    UnaryExpression(Keyword('with'), Namespace, WithType),
    UnaryExpression(Keyword('worldToScreen'), Array, Array),
    NullExpression(Keyword('HUDMovementLevels'), Array),
    NullExpression(Keyword('accTime'), Number),
    NullExpression(Keyword('activatedAddons'), Array),
    NullExpression(Keyword('agents'), Array),
    NullExpression(Keyword('airDensityCurveRTD'), Array),
    NullExpression(Keyword('all3DENEntities'), Array),
    NullExpression(Keyword('allCurators'), Array),
    NullExpression(Keyword('allCutLayers'), Array),
    NullExpression(Keyword('allDead'), Array),
    NullExpression(Keyword('allDeadMen'), Array),
    NullExpression(Keyword('allDisplays'), Array),
    NullExpression(Keyword('allGroups'), Array),
    NullExpression(Keyword('allMapMarkers'), Array),
    NullExpression(Keyword('allMines'), Array),
    NullExpression(Keyword('allPlayers'), Array),
    NullExpression(Keyword('allSites'), Array),
    NullExpression(Keyword('allUnits'), Array),
    NullExpression(Keyword('allUnitsUAV'), Array),
    NullExpression(Keyword('armoryPoints'), Number),
    NullExpression(Keyword('benchmark'), Number),
    NullExpression(Keyword('blufor'), Object),
    NullExpression(Keyword('briefingName'), String),
    NullExpression(Keyword('buldozer_IsEnabledRoadDiag'), Boolean),
    NullExpression(Keyword('buldozer_reloadOperMap'), Nothing),
    NullExpression(Keyword('cadetMode'), Boolean),
    NullExpression(Keyword('cameraOn'), Object),
    NullExpression(Keyword('cameraView'), String),
    NullExpression(Keyword('campaignConfigFile'), Config),
    NullExpression(Keyword('canSuspend'), Boolean),
    NullExpression(Keyword('cheatsEnabled'), Boolean),
    NullExpression(Keyword('civilian'), Object),
    NullExpression(Keyword('clearForcesRTD'), Nothing),
    NullExpression(Keyword('clearItemPool'), Nothing),
    NullExpression(Keyword('clearMagazinePool'), Nothing),
    NullExpression(Keyword('clearRadio'), Nothing),
    NullExpression(Keyword('clearWeaponPool'), Nothing),
    NullExpression(Keyword('clientOwner'), Number),
    NullExpression(Keyword('commandingMenu'), String),
    NullExpression(Keyword('configFile'), Config),
    NullExpression(Keyword('configNull'), Config),
    NullExpression(Keyword('controlNull'), Object),
    NullExpression(Keyword('copyFromClipboard'), String),
    NullExpression(Keyword('curatorCamera'), Object),
    NullExpression(Keyword('curatorMouseOver'), Object),
    NullExpression(Keyword('curatorSelected'), Array),
    NullExpression(Keyword('current3DENOperation'), String),
    NullExpression(Keyword('currentChannel'), Number),
    NullExpression(Keyword('currentNamespace'), Namespace, action=lambda i: missionNamespace),
    NullExpression(Keyword('cursorObject'), Object),
    NullExpression(Keyword('cursorTarget'), Object),
    NullExpression(Keyword('date'), Array),
    NullExpression(Keyword('dayTime'), Number),
    NullExpression(Keyword('diag_activeMissionFSMs'), Array),
    NullExpression(Keyword('diag_activeSQFScripts'), Array),
    NullExpression(Keyword('diag_activeSQSScripts'), Array),
    NullExpression(Keyword('diag_activeScripts'), Array),
    NullExpression(Keyword('diag_fps'), Number),
    NullExpression(Keyword('diag_fpsmin'), Number),
    NullExpression(Keyword('diag_frameno'), Number),
    NullExpression(Keyword('diag_tickTime'), Number),
    NullExpression(Keyword('dialog'), Boolean),
    NullExpression(Keyword('didJip'), Boolean),
    NullExpression(Keyword('difficulty'), Number),
    NullExpression(Keyword('difficultyEnabledRTD'), Boolean),
    NullExpression(Keyword('disableDebriefingStats'), Nothing),
    NullExpression(Keyword('disableSerialization'), Nothing),
    NullExpression(Keyword('displayNull'), Object),
    NullExpression(Keyword('distributionRegion'), Number),
    NullExpression(Keyword('dynamicSimulationSystemEnabled'), Boolean),
    NullExpression(Keyword('east'), Object),
    NullExpression(Keyword('enableEndDialog'), Nothing),
    NullExpression(Keyword('endLoadingScreen'), Nothing),
    NullExpression(Keyword('environmentEnabled'), Array),
    NullExpression(Keyword('estimatedEndServerTime'), Number),
    NullExpression(Keyword('exit'), Nothing),
    NullExpression(Keyword('false'), Boolean),
    NullExpression(Keyword('finishMissionInit'), Nothing),
    NullExpression(Keyword('fog'), Number),
    NullExpression(Keyword('fogForecast'), Number),
    NullExpression(Keyword('fogParams'), Array),
    NullExpression(Keyword('forceEnd'), Nothing),
    NullExpression(Keyword('forceWeatherChange'), Nothing),
    NullExpression(Keyword('forcedMap'), Array),
    NullExpression(Keyword('freeLook'), Boolean),
    NullExpression(Keyword('get3DENCamera'), Object),
    NullExpression(Keyword('get3DENIconsVisible'), Array),
    NullExpression(Keyword('get3DENLinesVisible'), Array),
    NullExpression(Keyword('get3DENMouseOver'), Array),
    NullExpression(Keyword('getArtilleryComputerSettings'), Array),
    NullExpression(Keyword('getClientState'), String),
    NullExpression(Keyword('getClientStateNumber'), Number),
    NullExpression(Keyword('getDLCAssetsUsage'), Array),
    NullExpression(Keyword('getElevationOffset'), Number),
    NullExpression(Keyword('getMissionDLCs'), Array),
    NullExpression(Keyword('getMissionLayers'), Array),
    NullExpression(Keyword('getMousePosition'), Array),
    NullExpression(Keyword('getObjectViewDistance'), Array),
    NullExpression(Keyword('getRemoteSensorsDisabled'), Boolean),
    NullExpression(Keyword('getResolution'), Array),
    NullExpression(Keyword('getShadowDistance'), Number),
    NullExpression(Keyword('getTerrainGrid'), Number),
    NullExpression(Keyword('getTotalDLCUsageTime'), Number),
    NullExpression(Keyword('groupIconSelectable'), Boolean),
    NullExpression(Keyword('groupIconsVisible'), Array),
    NullExpression(Keyword('grpNull'), Object),
    NullExpression(Keyword('gusts'), Number),
    NullExpression(Keyword('halt'), Nothing),
    NullExpression(Keyword('hasInterface'), Boolean),
    NullExpression(Keyword('hcShownBar'), Boolean),
    NullExpression(Keyword('humidity'), Number),
    NullExpression(Keyword('independent'), Object),
    NullExpression(Keyword('initAmbientLife'), Nothing),
    NullExpression(Keyword('is3DEN'), Boolean),
    NullExpression(Keyword('is3DENMultiplayer'), Boolean),
    NullExpression(Keyword('isAutotest'), Boolean),
    NullExpression(Keyword('isDedicated'), Boolean),
    NullExpression(Keyword('isFilePatchingEnabled'), Boolean),
    NullExpression(Keyword('isInstructorFigureEnabled'), Boolean),
    NullExpression(Keyword('isMultiplayer'), Boolean),
    NullExpression(Keyword('isMultiplayerSolo'), Boolean),
    NullExpression(Keyword('isPipEnabled'), Boolean),
    NullExpression(Keyword('isRemoteExecuted'), Boolean),
    NullExpression(Keyword('isRemoteExecutedJIP'), Boolean),
    NullExpression(Keyword('isServer'), Boolean),
    NullExpression(Keyword('isSteamMission'), Boolean),
    NullExpression(Keyword('isStreamFriendlyUIEnabled'), Boolean),
    NullExpression(Keyword('isStressDamageEnabled'), Boolean),
    NullExpression(Keyword('isTutHintsEnabled'), Boolean),
    NullExpression(Keyword('language'), String),
    NullExpression(Keyword('libraryCredits'), Array),
    NullExpression(Keyword('libraryDisclaimers'), Array),
    NullExpression(Keyword('lightnings'), Number),
    NullExpression(Keyword('lineBreak'), String),
    NullExpression(Keyword('loadGame'), Nothing),
    NullExpression(Keyword('locationNull'), Object),
    NullExpression(Keyword('logEntities'), Nothing),
    NullExpression(Keyword('mapAnimClear'), Nothing),
    NullExpression(Keyword('mapAnimCommit'), Nothing),
    NullExpression(Keyword('mapAnimDone'), Boolean),
    NullExpression(Keyword('markAsFinishedOnSteam'), Boolean),
    NullExpression(Keyword('missionConfigFile'), Config),
    NullExpression(Keyword('missionDifficulty'), Number),
    NullExpression(Keyword('missionName'), String),
    NullExpression(Keyword('missionNamespace'), Namespace, action=lambda i: missionNamespace),
    NullExpression(Keyword('missionStart'), Array),
    NullExpression(Keyword('missionVersion'), Number),
    NullExpression(Keyword('moonIntensity'), Number),
    NullExpression(Keyword('musicVolume'), Number),
    NullExpression(Keyword('netObjNull'), Object),
    NullExpression(Keyword('nextWeatherChange'), Number),
    NullExpression(Keyword('nil'), Nothing),
    NullExpression(Keyword('objNull'), Object),
    NullExpression(Keyword('openCuratorInterface'), Nothing),
    NullExpression(Keyword('opfor'), Object),
    NullExpression(Keyword('overcast'), Number),
    NullExpression(Keyword('overcastForecast'), Number),
    NullExpression(Keyword('parsingNamespace'), Namespace, action=lambda i: missionNamespace),
    NullExpression(Keyword('particlesQuality'), Number),
    NullExpression(Keyword('pi'), Number),
    NullExpression(Keyword('pixelGrid'), Number),
    NullExpression(Keyword('pixelGridBase'), Number),
    NullExpression(Keyword('pixelGridNoUIScale'), Number),
    NullExpression(Keyword('pixelH'), Number),
    NullExpression(Keyword('pixelW'), Number),
    NullExpression(Keyword('playableUnits'), Array),
    NullExpression(Keyword('player'), Object),
    NullExpression(Keyword('playerRespawnTime'), Number),
    NullExpression(Keyword('playerSide'), Object),
    NullExpression(Keyword('productVersion'), Array),
    NullExpression(Keyword('profileName'), String),
    NullExpression(Keyword('profileNameSteam'), String),
    NullExpression(Keyword('profileNamespace'), Namespace, action=lambda i: missionNamespace),
    NullExpression(Keyword('radioVolume'), Number),
    NullExpression(Keyword('rain'), Number),
    NullExpression(Keyword('rainbow'), Number),
    NullExpression(Keyword('resetCamShake'), Nothing),
    NullExpression(Keyword('resistance'), Object),
    NullExpression(Keyword('reversedMouseY'), Boolean),
    NullExpression(Keyword('runInitScript'), Nothing),
    NullExpression(Keyword('safeZoneH'), Number),
    NullExpression(Keyword('safeZoneW'), Number),
    NullExpression(Keyword('safeZoneWAbs'), Number),
    NullExpression(Keyword('safeZoneX'), Number),
    NullExpression(Keyword('safeZoneXAbs'), Number),
    NullExpression(Keyword('safeZoneY'), Number),
    NullExpression(Keyword('saveGame'), Nothing),
    NullExpression(Keyword('saveJoysticks'), Nothing),
    NullExpression(Keyword('saveProfileNamespace'), Nothing),
    NullExpression(Keyword('savingEnabled'), Boolean),
    NullExpression(Keyword('scriptNull'), Script),
    NullExpression(Keyword('selectNoPlayer'), Nothing),
    NullExpression(Keyword('serverName'), String),
    NullExpression(Keyword('serverTime'), Number),
    NullExpression(Keyword('shownArtilleryComputer'), Boolean),
    NullExpression(Keyword('shownChat'), Boolean),
    NullExpression(Keyword('shownCompass'), Boolean),
    NullExpression(Keyword('shownCuratorCompass'), Boolean),
    NullExpression(Keyword('shownGps'), Boolean),
    NullExpression(Keyword('shownHUD'), Array),
    NullExpression(Keyword('shownMap'), Boolean),
    NullExpression(Keyword('shownPad'), Boolean),
    NullExpression(Keyword('shownRadio'), Boolean),
    NullExpression(Keyword('shownScoretable'), Number),
    NullExpression(Keyword('shownUAVFeed'), Boolean),
    NullExpression(Keyword('shownWarrant'), Boolean),
    NullExpression(Keyword('shownWatch'), Boolean),
    NullExpression(Keyword('sideAmbientLife'), Object),
    NullExpression(Keyword('sideEmpty'), Object),
    NullExpression(Keyword('sideEnemy'), Object),
    NullExpression(Keyword('sideFriendly'), Object),
    NullExpression(Keyword('sideLogic'), Object),
    NullExpression(Keyword('sideUnknown'), Object),
    NullExpression(Keyword('simulWeatherSync'), Nothing),
    NullExpression(Keyword('slingLoadAssistantShown'), Boolean),
    NullExpression(Keyword('soundVolume'), Number),
    NullExpression(Keyword('sunOrMoon'), Number),
    NullExpression(Keyword('switchableUnits'), Array),
    NullExpression(Keyword('systemOfUnits'), Number),
    NullExpression(Keyword('taskNull'), Object),
    NullExpression(Keyword('teamMemberNull'), Object),
    NullExpression(Keyword('teamSwitch'), Nothing),
    NullExpression(Keyword('teamSwitchEnabled'), Boolean),
    NullExpression(Keyword('teams'), Array),
    NullExpression(Keyword('time'), Number),
    NullExpression(Keyword('timeMultiplier'), Number),
    NullExpression(Keyword('true'), Boolean),
    NullExpression(Keyword('uiNamespace'), Namespace, action=lambda i: missionNamespace),
    NullExpression(Keyword('userInputDisabled'), Boolean),
    NullExpression(Keyword('vehicles'), Array),
    NullExpression(Keyword('viewDistance'), Number),
    NullExpression(Keyword('visibleCompass'), Boolean),
    NullExpression(Keyword('visibleGps'), Boolean),
    NullExpression(Keyword('visibleMap'), Boolean),
    NullExpression(Keyword('visibleScoretable'), Boolean),
    NullExpression(Keyword('visibleWatch'), Boolean),
    NullExpression(Keyword('waves'), Number),
    NullExpression(Keyword('west'), Object),
    NullExpression(Keyword('wind'), Array),
    NullExpression(Keyword('windDir'), Number),
    NullExpression(Keyword('windRTD'), Array),
    NullExpression(Keyword('windStr'), Number),
    NullExpression(Keyword('worldName'), String),
    NullExpression(Keyword('worldSize'), Number),
]
